@@ -38,8 +38,8 @@ func (c *ConnectCARoot) Fetch(opts cache.FetchOptions, req cache.Request) (cache
 	reqReal = &dup
 
 	// Set the minimum query index to our current index so we block
-	reqReal.QueryOptions.MinQueryIndex = opts.MinIndex
-	reqReal.QueryOptions.MaxQueryTime = opts.Timeout
+	reqReal.MinQueryIndex = opts.MinIndex
+	reqReal.MaxQueryTime = opts.Timeout
 
 	// Fetch
 	var reply structs.IndexedCARoots
@@ -48,6 +48,6 @@ func (c *ConnectCARoot) Fetch(opts cache.FetchOptions, req cache.Request) (cache
 	}
 
 	result.Value = &reply
-	result.Index = reply.QueryMeta.Index
+	result.Index = reply.Index
 	return result, nil
 }
