@@ -24,8 +24,8 @@ func TestIntentionUpstreamsDestination(t *testing.T) {
 	rpc.On("RPC", mock.Anything, "Internal.IntentionUpstreamsDestination", mock.Anything, mock.Anything).Return(nil).
 		Run(func(args mock.Arguments) {
 			req := args.Get(2).(*structs.ServiceSpecificRequest)
-			require.Equal(t, uint64(24), req.QueryOptions.MinQueryIndex)
-			require.Equal(t, 1*time.Second, req.QueryOptions.MaxQueryTime)
+			require.Equal(t, uint64(24), req.MinQueryIndex)
+			require.Equal(t, 1*time.Second, req.MaxQueryTime)
 			require.True(t, req.AllowStale)
 			require.Equal(t, "foo", req.ServiceName)
 
@@ -34,7 +34,7 @@ func TestIntentionUpstreamsDestination(t *testing.T) {
 			}
 			reply := args.Get(3).(*structs.IndexedServiceList)
 			reply.Services = services
-			reply.QueryMeta.Index = 48
+			reply.Index = 48
 			resp = reply
 		})
 
