@@ -8,8 +8,9 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/go-viper/mapstructure/v2"
+
 	"github.com/hashicorp/hcl"
-	"github.com/mitchellh/mapstructure"
 
 	"github.com/hashicorp/consul/lib/decode"
 )
@@ -180,6 +181,7 @@ type Config struct {
 	EnableDebug                      *bool               `mapstructure:"enable_debug" json:"enable_debug,omitempty"`
 	EnableScriptChecks               *bool               `mapstructure:"enable_script_checks" json:"enable_script_checks,omitempty"`
 	EnableLocalScriptChecks          *bool               `mapstructure:"enable_local_script_checks" json:"enable_local_script_checks,omitempty"`
+	DisableKVKeyValidation           *bool               `mapstructure:"disable_kv_key_validation" json:"disable_kv_key_validation,omitempty"`
 	EnableSyslog                     *bool               `mapstructure:"enable_syslog" json:"enable_syslog,omitempty"`
 	EncryptKey                       *string             `mapstructure:"encrypt" json:"encrypt,omitempty"`
 	EncryptVerifyIncoming            *bool               `mapstructure:"encrypt_verify_incoming" json:"encrypt_verify_incoming,omitempty"`
@@ -214,6 +216,7 @@ type Config struct {
 	RaftSnapshotThreshold            *int                `mapstructure:"raft_snapshot_threshold" json:"raft_snapshot_threshold,omitempty"`
 	RaftSnapshotInterval             *string             `mapstructure:"raft_snapshot_interval" json:"raft_snapshot_interval,omitempty"`
 	RaftTrailingLogs                 *int                `mapstructure:"raft_trailing_logs" json:"raft_trailing_logs,omitempty"`
+	RaftPreVoteDisabled              *bool               `mapstructure:"raft_prevote_disabled" json:"raft_prevote_disabled,omitempty"`
 	ReconnectTimeoutLAN              *string             `mapstructure:"reconnect_timeout" json:"reconnect_timeout,omitempty"`
 	ReconnectTimeoutWAN              *string             `mapstructure:"reconnect_timeout_wan" json:"reconnect_timeout_wan,omitempty"`
 	RejoinAfterLeave                 *bool               `mapstructure:"rejoin_after_leave" json:"rejoin_after_leave,omitempty"`
@@ -388,6 +391,14 @@ type ServiceAddress struct {
 	Port    *int    `mapstructure:"port"`
 }
 
+type ServicePorts []ServicePort
+
+type ServicePort struct {
+	Name    *string `mapstructure:"name"`
+	Port    *int    `mapstructure:"port"`
+	Default *bool   `mapstructure:"default"`
+}
+
 type ServiceDefinition struct {
 	Kind              *string                   `mapstructure:"kind"`
 	ID                *string                   `mapstructure:"id"`
@@ -397,6 +408,7 @@ type ServiceDefinition struct {
 	TaggedAddresses   map[string]ServiceAddress `mapstructure:"tagged_addresses"`
 	Meta              map[string]string         `mapstructure:"meta"`
 	Port              *int                      `mapstructure:"port"`
+	Ports             ServicePorts              `mapstructure:"ports"`
 	SocketPath        *string                   `mapstructure:"socket_path"`
 	Check             *CheckDefinition          `mapstructure:"check"`
 	Checks            []CheckDefinition         `mapstructure:"checks"`
@@ -675,11 +687,12 @@ type HTTPConfig struct {
 }
 
 type Performance struct {
-	LeaveDrainTime        *string `mapstructure:"leave_drain_time"`
-	RaftMultiplier        *int    `mapstructure:"raft_multiplier"` // todo(fs): validate as uint
-	RPCHoldTimeout        *string `mapstructure:"rpc_hold_timeout"`
-	GRPCKeepaliveInterval *string `mapstructure:"grpc_keepalive_interval"`
-	GRPCKeepaliveTimeout  *string `mapstructure:"grpc_keepalive_timeout"`
+	LeaveDrainTime         *string `mapstructure:"leave_drain_time"`
+	RaftMultiplier         *int    `mapstructure:"raft_multiplier"` // todo(fs): validate as uint
+	RPCHoldTimeout         *string `mapstructure:"rpc_hold_timeout"`
+	GRPCKeepaliveInterval  *string `mapstructure:"grpc_keepalive_interval"`
+	GRPCKeepaliveTimeout   *string `mapstructure:"grpc_keepalive_timeout"`
+	EnableXDSLoadBalancing *bool   `mapstructure:"enable_xds_load_balancing"`
 }
 
 type Telemetry struct {
@@ -976,5 +989,6 @@ type License struct {
 }
 
 type Reporting struct {
-	License License `mapstructure:"license"`
+	License               License `mapstructure:"license"`
+	SnapshotRetentionTime *string `mapstructure:"snapshot_retention_time" json:"snapshot_retention_time,omitempty"`
 }
