@@ -13,6 +13,6 @@ import (
 // EnterpriseMeta stub
 type EnterpriseMeta struct{}
 
-func (_ *EnterpriseMeta) ToStructs() acl.EnterpriseMeta {
+func (*EnterpriseMeta) ToStructs() acl.EnterpriseMeta {
 	return *structs.DefaultEnterpriseMetaInDefaultPartition()
 }
