@@ -10,9 +10,10 @@ import (
 	"strings"
 	"time"
 
-	"github.com/hashicorp/go-uuid"
 	"golang.org/x/time/rate"
 
+	"github.com/hashicorp/go-uuid"
+
 	"github.com/hashicorp/consul/agent/cache"
 	"github.com/hashicorp/consul/agent/consul"
 	consulrate "github.com/hashicorp/consul/agent/consul/rate"
@@ -89,7 +90,7 @@ type RuntimeConfig struct {
 	// ACLEnableKeyListPolicy is used to opt-in to the "list" policy added to
 	// KV ACLs in Consul 1.0.
 	//
-	// See https://www.consul.io/docs/guides/acl.html#list-policy-for-keys for
+	// See https://developer.hashicorp.com/docs/guides/acl.html#list-policy-for-keys for
 	// more details.
 	//
 	// hcl: acl.enable_key_list_policy = (true|false)
@@ -669,6 +670,14 @@ type RuntimeConfig struct {
 	// flag: -enable-script-checks, -enable-local-script-checks
 	EnableLocalScriptChecks bool
 
+	// DisableKVKeyValidation controls whether KV key validation is disabled.
+	// When set to true, it disables validation that prevents path traversal and other
+	// security issues in KV key names. This can introduce security risks if not used carefully.
+	// We recommend keeping validation enabled (false) unless you have a specific reason to disable it.
+	//
+	// hcl: disable_kv_key_validation = (true|false)
+	DisableKVKeyValidation bool
+
 	// EnableRemoeScriptChecks controls whether health checks declared from the http API
 	// which execute scripts are enabled. This includes regular script checks and Docker
 	// checks.
@@ -738,6 +747,13 @@ type RuntimeConfig struct {
 	// time, the connection will be closed by the server.
 	GRPCKeepaliveTimeout time.Duration
 
+	// EnableXDSLoadBalancing controls xDS load balancing between the servers. Enabled by default.
+	// When enabled, Consul balances loads from xDS clients across available servers equally with an error margin of 0.1.
+	//
+	// When disabled, Consul does not restrict on the number of xDS connections on a server.
+	// In this scenario, you should deploy an external load balancer in front of the consul servers and distribute the load accordingly.
+	EnableXDSLoadBalancing bool
+
 	// HTTPAddrs contains the list of TCP addresses and UNIX sockets the HTTP
 	// server will bind to. If the HTTP endpoint is disabled (ports.http <= 0)
 	// the list is empty.
@@ -884,7 +900,7 @@ type RuntimeConfig struct {
 
 	// PrimaryGateways is a list of addresses and/or go-discover expressions to
 	// discovery the mesh gateways in the primary datacenter. See
-	// https://www.consul.io/docs/agent/config/cli-flags#cloud-auto-joining for
+	// https://developer.hashicorp.com/docs/agent/config/cli-flags#cloud-auto-joining for
 	// details.
 	//
 	// hcl: primary_gateways = []string
@@ -1004,6 +1020,9 @@ type RuntimeConfig struct {
 	// hcl: raft_trailing_logs = int
 	RaftTrailingLogs int
 
+	// hcl: raft_prevote_disabled = bool
+	RaftPreVoteDisabled bool
+
 	RaftLogStoreConfig consul.RaftLogStoreConfig
 
 	// ReconnectTimeoutLAN specifies the amount of time to wait to reconnect with
@@ -1083,7 +1102,7 @@ type RuntimeConfig struct {
 
 	// RetryJoinLAN is a list of addresses and/or go-discover expressions to
 	// join with retry enabled. See
-	// https://www.consul.io/docs/agent/config/cli-flags#cloud-auto-joining for
+	// https://developer.hashicorp.com/docs/agent/config/cli-flags#cloud-auto-joining for
 	// details.
 	//
 	// hcl: retry_join = []string
@@ -1108,7 +1127,7 @@ type RuntimeConfig struct {
 
 	// RetryJoinWAN is a list of addresses and/or go-discover expressions to
 	// join -wan with retry enabled. See
-	// https://www.consul.io/docs/agent/config/cli-flags#cloud-auto-joining for
+	// https://developer.hashicorp.com/docs/agent/config/cli-flags#cloud-auto-joining for
 	// details.
 	//
 	// hcl: retry_join_wan = []string
@@ -1491,7 +1510,7 @@ type RuntimeConfig struct {
 	// handler to act appropriately. These are managed entirely in the
 	// agent layer using the standard APIs.
 	//
-	// See https://www.consul.io/docs/agent/watches.html for details.
+	// See https://developer.hashicorp.com/docs/agent/watches.html for details.
 	//
 	// hcl: watches = [
 	//   { type=string ... },
@@ -1530,7 +1549,8 @@ type LicenseConfig struct {
 }
 
 type ReportingConfig struct {
-	License LicenseConfig
+	License               LicenseConfig
+	SnapshotRetentionTime time.Duration
 }
 
 type AutoConfig struct {
