@@ -306,7 +306,7 @@ func TestConfig_Apply(t *testing.T) {
 	_, err := a.srv.ConfigApply(resp, req)
 	require.NoError(t, err)
 	if resp.Code != 200 {
-		t.Fatalf(resp.Body.String())
+		t.Fatal(resp.Body.String())
 	}
 
 	// Get the remaining entry.
@@ -576,7 +576,7 @@ func TestConfig_Apply_CAS(t *testing.T) {
 	_, err := a.srv.ConfigApply(resp, req)
 	require.NoError(t, err)
 	if resp.Code != 200 {
-		t.Fatalf(resp.Body.String())
+		t.Fatal(resp.Body.String())
 	}
 
 	// Get the entry remaining entry.
