@@ -23,8 +23,6 @@ type CertURI interface {
 }
 
 var (
-	spiffeIDWorkloadIdentityRegexp = regexp.MustCompile(
-		`^(?:/ap/([^/]+))/ns/([^/]+)/identity/([^/]+)$`)
 	spiffeIDServiceRegexp = regexp.MustCompile(
 		`^(?:/ap/([^/]+))?/ns/([^/]+)/dc/([^/]+)/svc/([^/]+)$`)
 	spiffeIDAgentRegexp = regexp.MustCompile(
@@ -96,32 +94,6 @@ func ParseCertURI(input *url.URL) (CertURI, error) {
 			Datacenter: dc,
 			Service:    service,
 		}, nil
-	} else if v := spiffeIDWorkloadIdentityRegexp.FindStringSubmatch(path); v != nil {
-		// Determine the values. We assume they're reasonable to save cycles,
-		// but if the raw path is not empty that means that something is
-		// URL encoded so we go to the slow path.
-		ap := v[1]
-		ns := v[2]
-		workloadIdentity := v[3]
-		if input.RawPath != "" {
-			var err error
-			if ap, err = url.PathUnescape(v[1]); err != nil {
-				return nil, fmt.Errorf("Invalid admin partition: %s", err)
-			}
-			if ns, err = url.PathUnescape(v[2]); err != nil {
-				return nil, fmt.Errorf("Invalid namespace: %s", err)
-			}
-			if workloadIdentity, err = url.PathUnescape(v[3]); err != nil {
-				return nil, fmt.Errorf("Invalid workload identity: %s", err)
-			}
-		}
-
-		return &SpiffeIDWorkloadIdentity{
-			TrustDomain:      input.Host,
-			Partition:        ap,
-			Namespace:        ns,
-			WorkloadIdentity: workloadIdentity,
-		}, nil
 	} else if v := spiffeIDAgentRegexp.FindStringSubmatch(path); v != nil {
 		// Determine the values. We assume they're reasonable to save cycles,
 		// but if the raw path is not empty that means that something is
