@@ -17,6 +17,7 @@ import (
 
 	"github.com/hashicorp/consul/agent/checks"
 	consulrate "github.com/hashicorp/consul/agent/consul/rate"
+	"github.com/hashicorp/consul/agent/consul/reporting"
 	hcpconfig "github.com/hashicorp/consul/agent/hcp/config"
 	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/consul/internal/gossip/libserf"
@@ -463,6 +464,13 @@ type Config struct {
 	// ServerRejoinAgeMax is used to specify the duration of time a server
 	// is allowed to be down/offline before a startup operation is refused.
 	ServerRejoinAgeMax time.Duration
+
+	// EnableXDSLoadBalancing controls xDS load balancing between the servers. Enabled by default.
+	// When enabled, Consul balances loads from xDS clients across available servers equally with an error margin of 0.1.
+	//
+	// When disabled, Consul does not restrict on the number of xDS connections on a server.
+	// In this scenario, you should deploy an external load balancer in front of the consul servers and distribute the load accordingly.
+	EnableXDSLoadBalancing bool
 }
 
 func (c *Config) InPrimaryDatacenter() bool {
@@ -590,6 +598,8 @@ func DefaultConfig() *Config {
 		ServerRejoinAgeMax: 24 * 7 * time.Hour,
 	}
 
+	conf.Reporting.SnapshotRetentionTime = reporting.DefaultSnapshotRetention
+
 	// Increase our reap interval to 3 days instead of 24h.
 	conf.SerfLANConfig.ReconnectTimeout = 3 * 24 * time.Hour
 	conf.SerfWANConfig.ReconnectTimeout = 3 * 24 * time.Hour
@@ -663,6 +673,8 @@ func CloneSerfLANConfig(base *serf.Config) *serf.Config {
 	cfg.TombstoneTimeout = base.TombstoneTimeout
 	cfg.MemberlistConfig.SecretKey = base.MemberlistConfig.SecretKey
 	cfg.MetricLabels = base.MetricLabels
+	cfg.MsgpackUseNewTimeFormat = base.MsgpackUseNewTimeFormat
+	cfg.MemberlistConfig.MsgpackUseNewTimeFormat = base.MemberlistConfig.MsgpackUseNewTimeFormat
 
 	return cfg
 }
@@ -725,5 +737,6 @@ type License struct {
 }
 
 type Reporting struct {
-	License License
+	License               License
+	SnapshotRetentionTime time.Duration
 }
