@@ -14,12 +14,14 @@ import (
 	msgpackrpc "github.com/hashicorp/consul-net-rpc/net-rpc-msgpackrpc"
 
 	"github.com/hashicorp/consul/acl"
+	"github.com/hashicorp/consul/agent/netutil"
 	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/consul/sdk/testutil"
 )
 
 // Test basic creation
 func TestIntentionApply_new(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -192,6 +194,7 @@ func TestIntentionApply_createWithID(t *testing.T) {
 
 // Test basic updating
 func TestIntentionApply_updateGood(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -346,6 +349,7 @@ func TestIntentionApply_updateNonExist(t *testing.T) {
 
 // Test basic deleting
 func TestIntentionApply_deleteGood(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -404,6 +408,7 @@ func TestIntentionApply_deleteGood(t *testing.T) {
 }
 
 func TestIntentionApply_WithoutIDs(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -892,6 +897,7 @@ func TestIntentionApply_WithoutIDs(t *testing.T) {
 
 // Test apply with a deny ACL
 func TestIntentionApply_aclDeny(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -932,7 +938,7 @@ service "foobar" {
 	require.True(t, acl.IsErrPermissionDenied(err))
 
 	// Now add the token and try again.
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 	require.Nil(t, msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply))
 
 	// Read
@@ -960,6 +966,7 @@ service "foobar" {
 }
 
 func TestIntention_WildcardACLEnforcement(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1281,6 +1288,7 @@ func TestIntention_WildcardACLEnforcement(t *testing.T) {
 
 // Test apply with delete and a default deny ACL
 func TestIntentionApply_aclDelete(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1314,7 +1322,7 @@ service "foobar" {
 		Intention:  structs.TestIntention(t),
 	}
 	ixn.Intention.DestinationName = "foobar"
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 
 	// Create
 	var reply string
@@ -1323,12 +1331,12 @@ service "foobar" {
 	// Try to do a delete with no token; this should get rejected.
 	ixn.Op = structs.IntentionOpDelete
 	ixn.Intention.ID = reply
-	ixn.WriteRequest.Token = ""
+	ixn.Token = ""
 	err := msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply)
 	require.True(t, acl.IsErrPermissionDenied(err))
 
 	// Try again with the original token. This should go through.
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 	require.Nil(t, msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply))
 
 	// Verify it is gone
@@ -1346,6 +1354,7 @@ service "foobar" {
 
 // Test apply with update and a default deny ACL
 func TestIntentionApply_aclUpdate(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1379,7 +1388,7 @@ service "foobar" {
 		Intention:  structs.TestIntention(t),
 	}
 	ixn.Intention.DestinationName = "foobar"
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 
 	// Create
 	var reply string
@@ -1388,17 +1397,18 @@ service "foobar" {
 	// Try to do an update without a token; this should get rejected.
 	ixn.Op = structs.IntentionOpUpdate
 	ixn.Intention.ID = reply
-	ixn.WriteRequest.Token = ""
+	ixn.Token = ""
 	err := msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply)
 	require.True(t, acl.IsErrPermissionDenied(err))
 
 	// Try again with the original token; this should go through.
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 	require.Nil(t, msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply))
 }
 
 // Test apply with a management token
 func TestIntentionApply_aclManagement(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1425,7 +1435,7 @@ func TestIntentionApply_aclManagement(t *testing.T) {
 		Intention:  structs.TestIntention(t),
 	}
 	ixn.Intention.DestinationName = "foobar"
-	ixn.WriteRequest.Token = "root"
+	ixn.Token = "root"
 
 	// Create
 	var reply string
@@ -1443,6 +1453,7 @@ func TestIntentionApply_aclManagement(t *testing.T) {
 
 // Test update changing the name where an ACL won't allow it
 func TestIntentionApply_aclUpdateChange(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1476,7 +1487,7 @@ service "foobar" {
 		Intention:  structs.TestIntention(t),
 	}
 	ixn.Intention.DestinationName = "bar"
-	ixn.WriteRequest.Token = "root"
+	ixn.Token = "root"
 
 	// Create
 	var reply string
@@ -1486,13 +1497,14 @@ service "foobar" {
 	ixn.Op = structs.IntentionOpUpdate
 	ixn.Intention.ID = reply
 	ixn.Intention.DestinationName = "foo"
-	ixn.WriteRequest.Token = token
+	ixn.Token = token
 	err := msgpackrpc.CallWithCodec(codec, "Intention.Apply", &ixn, &reply)
 	require.True(t, acl.IsErrPermissionDenied(err))
 }
 
 // Test reading with ACLs
 func TestIntentionGet_acl(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1527,7 +1539,7 @@ func TestIntentionGet_acl(t *testing.T) {
 		Intention:  structs.TestIntention(t),
 	}
 	ixn.Intention.DestinationName = "foobar"
-	ixn.WriteRequest.Token = "root"
+	ixn.Token = "root"
 
 	// Create
 	var reply string
@@ -1622,6 +1634,7 @@ func TestIntentionList(t *testing.T) {
 
 // Test listing with ACLs
 func TestIntentionList_acl(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1654,7 +1667,7 @@ func TestIntentionList_acl(t *testing.T) {
 		ixn.Intention.SourceNS = "default"
 		ixn.Intention.DestinationNS = "default"
 		ixn.Intention.DestinationName = name
-		ixn.WriteRequest.Token = TestDefaultInitialManagementToken
+		ixn.Token = TestDefaultInitialManagementToken
 
 		// Create
 		var reply string
@@ -1669,7 +1682,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 0)
-		require.False(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
+		require.False(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
 	})
 
 	// Test with management token
@@ -1681,7 +1694,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 3)
-		require.False(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
+		require.False(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
 	})
 
 	// Test with user token
@@ -1693,7 +1706,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 1)
-		require.True(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
+		require.True(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
 	})
 
 	// maskResultsFilteredByACLs() in rpc.go sets ResultsFilteredByACLs to false if the token is an empty string
@@ -1709,7 +1722,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 0)
-		require.False(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
+		require.False(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
 	})
 
 	// has access to everything
@@ -1725,7 +1738,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 1)
-		require.False(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
+		require.False(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
 	})
 
 	// ResultsFilteredByACLs should reflect user does not have access to read all intentions but has access to some.
@@ -1741,7 +1754,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 1)
-		require.True(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
+		require.True(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
 	})
 
 	// ResultsFilteredByACLs need to act as though no filter was applied.
@@ -1757,7 +1770,7 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 0)
-		require.True(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
+		require.True(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
 	})
 
 	// ResultsFilteredByACLs should reflect user does not have access to read any intentions
@@ -1773,13 +1786,14 @@ func TestIntentionList_acl(t *testing.T) {
 		var resp structs.IndexedIntentions
 		require.NoError(t, msgpackrpc.CallWithCodec(codec, "Intention.List", req, &resp))
 		require.Len(t, resp.Intentions, 0)
-		require.True(t, resp.QueryMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be true")
+		require.False(t, resp.ResultsFilteredByACLs, "ResultsFilteredByACLs should be false")
 	})
 }
 
 // Test basic matching. We don't need to exhaustively test inputs since this
 // is tested in the agent/consul/state package.
 func TestIntentionMatch_good(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1852,6 +1866,7 @@ func TestIntentionMatch_good(t *testing.T) {
 }
 
 func TestIntentionMatch_BlockOnNoChange(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -1878,7 +1893,7 @@ func TestIntentionMatch_BlockOnNoChange(t *testing.T) {
 						},
 					},
 				}
-				args.QueryOptions.MinQueryIndex = minQueryIndex
+				args.MinQueryIndex = minQueryIndex
 
 				var out structs.IndexedIntentionMatches
 				errCh := channelCallRPC(s1, "Intention.Match", args, &out, func() error {
@@ -1972,7 +1987,7 @@ func TestIntentionMatch_acl(t *testing.T) {
 				Intention:  structs.TestIntention(t),
 			}
 			ixn.Intention.DestinationName = v
-			ixn.WriteRequest.Token = TestDefaultInitialManagementToken
+			ixn.Token = TestDefaultInitialManagementToken
 
 			// Create
 			var reply string
@@ -2159,6 +2174,7 @@ service "bar" {
 
 // Test the Check method returns allow/deny properly.
 func TestIntentionCheck_match(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
