@@ -7,6 +7,7 @@ import (
 	"context"
 	"fmt"
 	"net"
+	"strconv"
 	"testing"
 	"time"
 
@@ -84,6 +85,107 @@ func TestPeeringBackend_ForwardToLeader(t *testing.T) {
 	})
 }
 
+func TestPeeringBackend_GetLocalServerAddresses_IPv6(t *testing.T) {
+	if testing.Short() {
+		t.Skip("too slow for testing.Short")
+	}
+
+	_, cfg := testServerConfigIPv6(t)
+	cfg.GRPCTLSPort = freeport.GetOne(t)
+
+	srv, err := newServer(t, cfg)
+	require.NoError(t, err)
+	testrpc.WaitForLeader(t, srv.RPC, "dc1")
+
+	backend := NewPeeringBackend(srv)
+
+	testutil.RunStep(t, "peer to servers", func(t *testing.T) {
+		addrs, err := backend.GetLocalServerAddresses()
+		require.NoError(t, err)
+
+		expect := net.JoinHostPort("::1", strconv.Itoa(srv.config.GRPCTLSPort))
+		require.Equal(t, []string{expect}, addrs)
+	})
+
+	testutil.RunStep(t, "prefer WAN address for servers", func(t *testing.T) {
+		req := structs.RegisterRequest{
+			Datacenter:     cfg.Datacenter,
+			Node:           cfg.NodeName,
+			ID:             cfg.NodeID,
+			Address:        "::1",
+			EnterpriseMeta: *acl.DefaultEnterpriseMeta(),
+
+			// Add a tagged WAN address to the server registration
+			TaggedAddresses: map[string]string{
+				structs.TaggedAddressWAN: "4343:ffda:2344:3434:3222::5",
+			},
+		}
+		require.NoError(t, srv.fsm.State().EnsureRegistration(200, &req))
+
+		addrs, err := backend.GetLocalServerAddresses()
+		require.NoError(t, err)
+		expect := net.JoinHostPort("4343:ffda:2344:3434:3222::5", strconv.Itoa(srv.config.GRPCTLSPort))
+		require.Equal(t, []string{expect}, addrs)
+	})
+
+	testutil.RunStep(t, "existence of mesh config entry is not enough to peer through gateways", func(t *testing.T) {
+		mesh := structs.MeshConfigEntry{
+			// Enable unrelated config.
+			TransparentProxy: structs.TransparentProxyMeshConfig{
+				MeshDestinationsOnly: true,
+			},
+		}
+
+		require.NoError(t, srv.fsm.State().EnsureConfigEntry(1, &mesh))
+		addrs, err := backend.GetLocalServerAddresses()
+		require.NoError(t, err)
+
+		// Still expect server address because PeerThroughMeshGateways was not enabled.
+		expect := net.JoinHostPort("4343:ffda:2344:3434:3222::5", strconv.Itoa(srv.config.GRPCTLSPort))
+
+		require.Equal(t, []string{expect}, addrs)
+	})
+
+	testutil.RunStep(t, "cannot peer through gateways without registered gateways", func(t *testing.T) {
+		mesh := structs.MeshConfigEntry{
+			Peering: &structs.PeeringMeshConfig{PeerThroughMeshGateways: true},
+		}
+		require.NoError(t, srv.fsm.State().EnsureConfigEntry(1, &mesh))
+
+		addrs, err := backend.GetLocalServerAddresses()
+		require.Nil(t, addrs)
+		testutil.RequireErrorContains(t, err,
+			"servers are configured to PeerThroughMeshGateways, but no mesh gateway instances are registered")
+	})
+
+	testutil.RunStep(t, "peer through mesh gateways", func(t *testing.T) {
+		reg := structs.RegisterRequest{
+			ID:      types.NodeID("b5489ca9-f5e9-4dba-a779-61fec4e8e364"),
+			Node:    "gw-node",
+			Address: "::1",
+			TaggedAddresses: map[string]string{
+				structs.TaggedAddressWAN: "2406:da1a:23:5e05:e1c6::5",
+			},
+			Service: &structs.NodeService{
+				ID:      "mesh-gateway",
+				Service: "mesh-gateway",
+				Kind:    structs.ServiceKindMeshGateway,
+				Port:    443,
+				TaggedAddresses: map[string]structs.ServiceAddress{
+					structs.TaggedAddressWAN: {Address: "2406:da1a:23:5e05:e1c6:aaaa:5", Port: 8443},
+				},
+			},
+		}
+		require.NoError(t, srv.fsm.State().EnsureRegistration(2, &reg))
+
+		addrs, err := backend.GetLocalServerAddresses()
+		require.NoError(t, err)
+		expect := net.JoinHostPort("2406:da1a:23:5e05:e1c6:aaaa:5", "8443")
+
+		require.Equal(t, []string{expect}, addrs)
+	})
+}
+
 func TestPeeringBackend_GetLocalServerAddresses(t *testing.T) {
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
