@@ -33,14 +33,12 @@ import (
 	"github.com/hashicorp/consul/acl"
 	"github.com/hashicorp/consul/agent/connect"
 	"github.com/hashicorp/consul/agent/consul/rate"
-	rpcRate "github.com/hashicorp/consul/agent/consul/rate"
 	"github.com/hashicorp/consul/agent/consul/state"
 	agent_grpc "github.com/hashicorp/consul/agent/grpc-internal"
 	"github.com/hashicorp/consul/agent/pool"
 	"github.com/hashicorp/consul/agent/structs"
 	tokenStore "github.com/hashicorp/consul/agent/token"
 	"github.com/hashicorp/consul/api"
-	"github.com/hashicorp/consul/lib"
 	"github.com/hashicorp/consul/proto/private/pbsubscribe"
 	"github.com/hashicorp/consul/sdk/testutil"
 	"github.com/hashicorp/consul/sdk/testutil/retry"
@@ -235,9 +233,17 @@ func (m *MockSink) Close() error {
 // other blocking query tests reside in blockingquery_test.go in the blockingquery package.
 func TestServer_blockingQuery(t *testing.T) {
 	t.Parallel()
-	_, s := testServerWithConfig(t)
+	_, s := testServerWithConfig(t, testServerACLConfig)
+	delegate := ACLResolverTestDelegate{
+		enabled:    true,
+		datacenter: "dc1",
+	}
+	delegate.tokenReadFn = delegate.defaultTokenReadFn(errRPC)
+	r := newTestACLResolver(t, &delegate, nil)
+	s.ACLResolver = r
 
 	t.Run("ResultsFilteredByACLs is reset for unauthenticated calls", func(t *testing.T) {
+		// empty token
 		opts := structs.QueryOptions{
 			Token: "",
 		}
@@ -250,24 +256,36 @@ func TestServer_blockingQuery(t *testing.T) {
 		err := s.blockingQuery(&opts, &meta, fn)
 		require.NoError(t, err)
 		require.False(t, meta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be reset for unauthenticated calls")
-	})
 
-	t.Run("ResultsFilteredByACLs is honored for authenticated calls", func(t *testing.T) {
-		token, err := lib.GenerateUUID(nil)
-		require.NoError(t, err)
-
-		opts := structs.QueryOptions{
-			Token: token,
+		// anonymous token
+		anonOpts := structs.QueryOptions{
+			Token: "anonymous", // secret id of anonymous token
 		}
-		var meta structs.QueryMeta
-		fn := func(_ memdb.WatchSet, _ *state.Store) error {
-			meta.ResultsFilteredByACLs = true
+		var anonMeta structs.QueryMeta
+		anonFn := func(_ memdb.WatchSet, _ *state.Store) error {
+			anonMeta.ResultsFilteredByACLs = true
 			return nil
 		}
 
-		err = s.blockingQuery(&opts, &meta, fn)
+		err = s.blockingQuery(&anonOpts, &anonMeta, anonFn)
 		require.NoError(t, err)
-		require.True(t, meta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be honored for authenticated calls")
+		require.False(t, anonMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be reset for unauthenticated calls")
+	})
+
+	t.Run("ResultsFilteredByACLs is honored for authenticated calls", func(t *testing.T) {
+		delegate.localTokens = true
+		authOpts := structs.QueryOptions{
+			Token: "authenticated",
+		}
+		var authMeta structs.QueryMeta
+		authFn := func(_ memdb.WatchSet, _ *state.Store) error {
+			authMeta.ResultsFilteredByACLs = true
+			return nil
+		}
+
+		err := s.blockingQuery(&authOpts, &authMeta, authFn)
+		require.NoError(t, err)
+		require.True(t, authMeta.ResultsFilteredByACLs, "ResultsFilteredByACLs should be honored for authenticated calls")
 	})
 }
 
@@ -817,7 +835,7 @@ func TestRPC_LocalTokenStrippedOnForward(t *testing.T) {
 	var out bool
 	err = msgpackrpc.CallWithCodec(codec2, "KVS.Apply", &arg, &out)
 	require.NoError(t, err)
-	require.Equal(t, localToken2.SecretID, arg.WriteRequest.Token, "token should not be stripped")
+	require.Equal(t, localToken2.SecretID, arg.Token, "token should not be stripped")
 
 	// Try to use it remotely
 	arg = structs.KVSRequest{
@@ -866,7 +884,7 @@ func TestRPC_LocalTokenStrippedOnForward(t *testing.T) {
 	}
 	err = msgpackrpc.CallWithCodec(codec2, "KVS.Apply", &arg, &out)
 	require.NoError(t, err)
-	require.Equal(t, localToken2.SecretID, arg.WriteRequest.Token, "token should not be stripped")
+	require.Equal(t, localToken2.SecretID, arg.Token, "token should not be stripped")
 }
 
 func TestRPC_LocalTokenStrippedOnForward_GRPC(t *testing.T) {
@@ -1080,7 +1098,7 @@ func TestCanRetry(t *testing.T) {
 	config.RPCHoldTimeout = 7 * time.Second
 	retryableMessages := []error{
 		ErrChunkingResubmit,
-		rpcRate.ErrRetryElsewhere,
+		rate.ErrRetryElsewhere,
 	}
 	run := func(t *testing.T, tc testCase) {
 		timeOutValue := tc.timeout
