@@ -53,7 +53,6 @@ import (
 	"github.com/hashicorp/consul/agent/consul/xdscapacity"
 	"github.com/hashicorp/consul/agent/grpc-external/services/peerstream"
 	"github.com/hashicorp/consul/agent/hcp"
-	"github.com/hashicorp/consul/agent/hcp/bootstrap"
 	hcpclient "github.com/hashicorp/consul/agent/hcp/client"
 	logdrop "github.com/hashicorp/consul/agent/log-drop"
 	"github.com/hashicorp/consul/agent/metadata"
@@ -65,7 +64,6 @@ import (
 	"github.com/hashicorp/consul/agent/token"
 	"github.com/hashicorp/consul/internal/controller"
 	"github.com/hashicorp/consul/internal/gossip/librtt"
-	hcpctl "github.com/hashicorp/consul/internal/hcp"
 	"github.com/hashicorp/consul/internal/multicluster"
 	"github.com/hashicorp/consul/internal/resource"
 	"github.com/hashicorp/consul/internal/resource/demo"
@@ -783,7 +781,7 @@ func NewServer(config *Config, flat Deps, externalGRPCServer *grpc.Server,
 			if err != nil {
 				return "", err
 			}
-			return fmt.Sprintf("%s:%d", addr, s.WanJoinPort), nil
+			return net.JoinHostPort(addr, strconv.Itoa(s.WanJoinPort)), nil
 		}
 		go s.Flood(addrFn, s.serfWAN)
 	}
@@ -819,8 +817,9 @@ func NewServer(config *Config, flat Deps, externalGRPCServer *grpc.Server,
 	s.overviewManager = NewOverviewManager(s.logger, s.fsm, s.config.MetricsReportingInterval)
 	go s.overviewManager.Run(&lib.StopChannelContext{StopCh: s.shutdownCh})
 
-	s.reportingManager = reporting.NewReportingManager(s.logger, getEnterpriseReportingDeps(flat), s, s.fsm.State())
-	go s.reportingManager.Run(&lib.StopChannelContext{StopCh: s.shutdownCh})
+	s.reportingManager = reporting.NewReportingManager(s.logger, config.Datacenter, config.Reporting.License.Enabled, getEnterpriseReportingDeps(flat), s, s.fsm.State(), config.Reporting.SnapshotRetentionTime)
+	go s.reportingManager.RunMetricsWriter(&lib.StopChannelContext{StopCh: s.shutdownCh})
+	go s.reportingManager.RunManualSnapshotWriter(&lib.StopChannelContext{StopCh: s.shutdownCh})
 
 	// configure the server specific grpc interfaces (in-process + internal multiplexed grpc)
 	if err := s.setupGRPCInterfaces(config, flat); err != nil {
@@ -838,25 +837,6 @@ func NewServer(config *Config, flat Deps, externalGRPCServer *grpc.Server,
 	// to enable RPC forwarding.
 	s.grpcLeaderForwarder = flat.LeaderForwarder
 
-	if s.config.Cloud.IsConfigured() {
-		// Start watching HCP Link resource. This needs to be created after
-		// the GRPC services are set up in order for the resource service client to
-		// function. This uses the insecure grpc channel so that it doesn't need to
-		// present a valid ACL token.
-		go hcp.RunHCPLinkWatcher(
-			&lib.StopChannelContext{StopCh: shutdownCh},
-			logger.Named("hcp-link-watcher"),
-			pbresource.NewResourceServiceClient(s.insecureSafeGRPCChan),
-			hcp.HCPManagerLifecycleFn(
-				s.hcpManager,
-				hcpclient.NewClient,
-				bootstrap.LoadManagementToken,
-				flat.HCP.Config,
-				flat.HCP.DataDir,
-			),
-		)
-	}
-
 	s.controllerManager = controller.NewManager(
 		// Usage of the insecure + unsafe grpc chan is required for the controller
 		// manager. It must be unauthorized so that controllers do not need to
@@ -878,9 +858,10 @@ func NewServer(config *Config, flat Deps, externalGRPCServer *grpc.Server,
 	go s.trackLeaderChanges()
 
 	s.xdsCapacityController = xdscapacity.NewController(xdscapacity.Config{
-		Logger:         s.logger.Named(logging.XDSCapacityController),
-		GetStore:       func() xdscapacity.Store { return s.fsm.State() },
-		SessionLimiter: flat.XDSStreamLimiter,
+		Logger:                 s.logger.Named(logging.XDSCapacityController),
+		GetStore:               func() xdscapacity.Store { return s.fsm.State() },
+		SessionLimiter:         flat.XDSStreamLimiter,
+		EnableXDSLoadBalancing: s.config.EnableXDSLoadBalancing,
 	})
 	go s.xdsCapacityController.Run(&lib.StopChannelContext{StopCh: s.shutdownCh})
 
@@ -928,15 +909,7 @@ func NewServer(config *Config, flat Deps, externalGRPCServer *grpc.Server,
 	return s, nil
 }
 
-func (s *Server) registerControllers(deps Deps) error {
-	if s.config.Cloud.IsConfigured() {
-		hcpctl.RegisterControllers(
-			s.controllerManager, hcpctl.ControllerDependencies{
-				CloudConfig: deps.HCP.Config,
-			},
-		)
-	}
-
+func (s *Server) registerControllers(_ Deps) error {
 	shim := NewExportedServicesShim(s)
 	multicluster.RegisterCompatControllers(s.controllerManager, multicluster.DefaultCompatControllerDependencies(shim))
 
@@ -1356,7 +1329,7 @@ func (s *Server) Shutdown() error {
 	}
 
 	if s.ACLResolver != nil {
-		s.ACLResolver.Close()
+		s.Close()
 	}
 
 	if s.fsm != nil {
@@ -2146,7 +2119,7 @@ const peersInfoContent = `
 As of Consul 0.7.0, the peers.json file is only used for recovery
 after an outage. The format of this file depends on what the server has
 configured for its Raft protocol version. Please see the agent configuration
-page at https://www.consul.io/docs/agent/config/cli-flags#_raft_protocol for more
+page at https://developer.hashicorp.com/docs/agent/config/cli-flags#_raft_protocol for more
 details about this parameter.
 
 For Raft protocol version 2 and earlier, this should be formatted as a JSON
@@ -2189,7 +2162,7 @@ The "address" field is the address and port of the server.
 
 The "non_voter" field controls whether the server is a non-voter, which is used
 in some advanced Autopilot configurations, please see
-https://www.consul.io/docs/guides/autopilot.html for more information. If
+https://developer.hashicorp.com/docs/guides/autopilot.html for more information. If
 "non_voter" is omitted it will default to false, which is typical for most
 clusters.
 
@@ -2206,5 +2179,5 @@ creating the peers.json file, and that all servers receive the same
 configuration. Once the peers.json file is successfully ingested and applied, it
 will be deleted.
 
-Please see https://www.consul.io/docs/guides/outage.html for more information.
+Please see https://developer.hashicorp.com/docs/guides/outage.html for more information.
 `
