@@ -451,11 +451,11 @@ func ServiceHealthEventsFromChanges(tx ReadTxn, changes Changes) ([]stream.Event
 					e.Topic = EventTopicServiceHealthConnect
 					payload := e.Payload.(EventPayloadCheckServiceNode)
 					payload.overrideKey = serviceName.Name
-					if gatewayName.EnterpriseMeta.NamespaceOrDefault() != serviceName.EnterpriseMeta.NamespaceOrDefault() {
-						payload.overrideNamespace = serviceName.EnterpriseMeta.NamespaceOrDefault()
+					if gatewayName.NamespaceOrDefault() != serviceName.NamespaceOrDefault() {
+						payload.overrideNamespace = serviceName.NamespaceOrDefault()
 					}
-					if gatewayName.EnterpriseMeta.PartitionOrDefault() != serviceName.EnterpriseMeta.PartitionOrDefault() {
-						payload.overridePartition = serviceName.EnterpriseMeta.PartitionOrDefault()
+					if gatewayName.PartitionOrDefault() != serviceName.PartitionOrDefault() {
+						payload.overridePartition = serviceName.PartitionOrDefault()
 					}
 					e.Payload = payload
 
@@ -484,11 +484,11 @@ func ServiceHealthEventsFromChanges(tx ReadTxn, changes Changes) ([]stream.Event
 				e.Topic = EventTopicServiceHealthConnect
 				payload := e.Payload.(EventPayloadCheckServiceNode)
 				payload.overrideKey = serviceName.Name
-				if gatewayName.EnterpriseMeta.NamespaceOrDefault() != serviceName.EnterpriseMeta.NamespaceOrDefault() {
-					payload.overrideNamespace = serviceName.EnterpriseMeta.NamespaceOrDefault()
+				if gatewayName.NamespaceOrDefault() != serviceName.NamespaceOrDefault() {
+					payload.overrideNamespace = serviceName.NamespaceOrDefault()
 				}
-				if gatewayName.EnterpriseMeta.PartitionOrDefault() != serviceName.EnterpriseMeta.PartitionOrDefault() {
-					payload.overridePartition = serviceName.EnterpriseMeta.PartitionOrDefault()
+				if gatewayName.PartitionOrDefault() != serviceName.PartitionOrDefault() {
+					payload.overridePartition = serviceName.PartitionOrDefault()
 				}
 				e.Payload = payload
 
@@ -625,11 +625,11 @@ func copyEventForService(event stream.Event, service structs.ServiceName) stream
 	event.Topic = EventTopicServiceHealthConnect
 	payload := event.Payload.(EventPayloadCheckServiceNode)
 	payload.overrideKey = service.Name
-	if payload.Value.Service.EnterpriseMeta.NamespaceOrDefault() != service.EnterpriseMeta.NamespaceOrDefault() {
-		payload.overrideNamespace = service.EnterpriseMeta.NamespaceOrDefault()
+	if payload.Value.Service.NamespaceOrDefault() != service.NamespaceOrDefault() {
+		payload.overrideNamespace = service.NamespaceOrDefault()
 	}
-	if payload.Value.Service.EnterpriseMeta.PartitionOrDefault() != service.EnterpriseMeta.PartitionOrDefault() {
-		payload.overridePartition = service.EnterpriseMeta.PartitionOrDefault()
+	if payload.Value.Service.PartitionOrDefault() != service.PartitionOrDefault() {
+		payload.overridePartition = service.PartitionOrDefault()
 	}
 
 	event.Payload = payload
@@ -718,9 +718,7 @@ func getNodeAndChecks(tx ReadTxn, node string, entMeta *acl.EnterpriseMeta, peer
 		// Create a new slice so that append does not modify the array backing nodeChecks.
 		result := make(structs.HealthChecks, 0, len(nodeChecks))
 		result = append(result, nodeChecks...)
-		for _, check := range svcChecks[serviceID] {
-			result = append(result, check)
-		}
+		result = append(result, svcChecks[serviceID]...)
 		return result
 	}
 	return n, serviceChecks, nil
