@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package state
 
 import (
@@ -5,14 +8,15 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/go-memdb"
+
+	"github.com/hashicorp/consul/agent/structs"
 )
 
 func TestStateStore_PreparedQuery_isUUID(t *testing.T) {
 	cases := map[string]bool{
-		"":     false,
-		"nope": false,
+		"":                                      false,
+		"nope":                                  false,
 		"f004177f-2c28-83b7-4229-eacc25fe55d1":  true,
 		"F004177F-2C28-83B7-4229-EACC25FE55D1":  true,
 		"x004177f-2c28-83b7-4229-eacc25fe55d1":  false, // Bad hex
@@ -35,6 +39,10 @@ func TestStateStore_PreparedQuery_isUUID(t *testing.T) {
 }
 
 func TestStateStore_PreparedQuerySet_PreparedQueryGet(t *testing.T) {
+	if testing.Short() {
+		t.Skip("too slow for testing.Short")
+	}
+
 	s := testStateStore(t)
 
 	// Querying with no results returns nil.
@@ -68,7 +76,7 @@ func TestStateStore_PreparedQuerySet_PreparedQueryGet(t *testing.T) {
 
 	// The set will still fail because the session is bogus.
 	err = s.PreparedQuerySet(1, query)
-	if err == nil || !strings.Contains(err.Error(), "failed session lookup") {
+	if err == nil || !strings.Contains(err.Error(), "invalid session") {
 		t.Fatalf("bad: %v", err)
 	}
 
@@ -659,7 +667,7 @@ func TestStateStore_PreparedQueryResolve(t *testing.T) {
 			Regexp: "^prod-(.*)$",
 		},
 		Service: structs.ServiceQuery{
-			Service: "${match(1)}-master",
+			Service: "${match(1)}-primary",
 		},
 	}
 	if err := s.PreparedQuerySet(5, tmpl2); err != nil {
@@ -701,7 +709,7 @@ func TestStateStore_PreparedQueryResolve(t *testing.T) {
 			Regexp: "^prod-(.*)$",
 		},
 		Service: structs.ServiceQuery{
-			Service: "redis-foobar-master",
+			Service: "redis-foobar-primary",
 		},
 		RaftIndex: structs.RaftIndex{
 			CreateIndex: 5,
