@@ -14,6 +14,7 @@ import (
 	"github.com/miekg/dns"
 	"github.com/stretchr/testify/require"
 
+	"github.com/hashicorp/consul/agent/netutil"
 	"github.com/hashicorp/consul/agent/structs"
 	"github.com/hashicorp/consul/api"
 	"github.com/hashicorp/consul/lib"
@@ -520,6 +521,7 @@ func TestDNS_ServiceLookupWithInternalServiceAddress(t *testing.T) {
 }
 
 func TestDNS_ConnectServiceLookup(t *testing.T) {
+	netutil.GetAgentBindAddrFunc = netutil.GetMockGetAgentBindAddrFunc("0.0.0.0")
 	if testing.Short() {
 		t.Skip("too slow for testing.Short")
 	}
@@ -3850,3 +3852,129 @@ func TestDNS_ServiceLookup_SuppressTXT(t *testing.T) {
 	}
 	require.Equal(t, wantAdditional, in.Extra)
 }
+
+func TestDNS_ServiceLookup_MultiPort_SRV(t *testing.T) {
+	if testing.Short() {
+		t.Skip("too slow for testing.Short")
+	}
+
+	a := NewTestAgent(t, "")
+	defer a.Shutdown()
+	testrpc.WaitForLeader(t, a.RPC, "dc1")
+
+	// Register a multiport node
+	{
+		args := &structs.RegisterRequest{
+			Datacenter: "dc1",
+			Node:       "foo",
+			Address:    "127.0.0.1",
+			Service: &structs.NodeService{
+				Service: "multiport",
+				Ports: structs.ServicePorts{
+					{
+						Name:    "http",
+						Port:    8080,
+						Default: true,
+					},
+					{
+						Name: "metrics",
+						Port: 9090,
+					},
+				},
+			},
+		}
+
+		var out struct{}
+		if err := a.RPC(context.Background(), "Catalog.Register", args, &out); err != nil {
+			t.Fatalf("err: %v", err)
+		}
+	}
+
+	// Register a singleport service
+	{
+		args := &structs.RegisterRequest{
+			Datacenter: "dc1",
+			Node:       "foo",
+			Address:    "127.0.0.1",
+			Service: &structs.NodeService{
+				Service: "singleport",
+				Port:    8080,
+			},
+		}
+
+		var out struct{}
+		if err := a.RPC(context.Background(), "Catalog.Register", args, &out); err != nil {
+			t.Fatalf("err: %v", err)
+		}
+	}
+
+	type testCase struct {
+		dnsQuery     string
+		expectedPort int
+		expectedCode int
+	}
+
+	cases := map[string]testCase{
+		"multiport_no_port_name": {
+			dnsQuery:     "_multiport._tcp.service.consul.",
+			expectedPort: 8080,
+		},
+		"multiport_http_port": {
+			dnsQuery:     "_multiport._tcp.service.http.port.consul.",
+			expectedPort: 8080,
+		},
+		"multiport_metrics_port": {
+			dnsQuery:     "_multiport._tcp.service.metrics.port.consul.",
+			expectedPort: 9090,
+		},
+		"multiport_unknown_port": {
+			dnsQuery:     "_multiport._tcp.service.unknown.port.consul.",
+			expectedCode: dns.RcodeNameError,
+		},
+		"multiport_known_dc_known_port": {
+			dnsQuery:     "_multiport._tcp.service.dc1.dc.http.port.consul.",
+			expectedPort: 8080,
+		},
+		"multiport_known_dc_unknown_port": {
+			dnsQuery:     "_multiport._tcp.service.dc1.dc.unknown.port.consul.",
+			expectedCode: dns.RcodeNameError,
+		},
+		"singleport_no_port_name": {
+			dnsQuery:     "_singleport._tcp.service.consul.",
+			expectedPort: 8080,
+		},
+		"singeport_http_port": {
+			dnsQuery:     "_singleport._tcp.service.http.port.consul.",
+			expectedCode: dns.RcodeNameError,
+		},
+	}
+
+	for name, tc := range cases {
+		t.Run(name, func(t *testing.T) {
+			m := new(dns.Msg)
+			m.SetQuestion(tc.dnsQuery, dns.TypeSRV)
+
+			c := new(dns.Client)
+			in, _, err := c.Exchange(m, a.DNSAddr())
+			if err != nil {
+				t.Fatalf("err: %v", err)
+			}
+
+			if in.Rcode != tc.expectedCode {
+				t.Fatalf("Expected code %v error, got: %v", tc.expectedCode, in.Rcode)
+			}
+
+			if tc.expectedCode != 0 {
+				return
+			}
+
+			require.NoError(t, err)
+			require.Len(t, in.Answer, 1, "Expected 1 SRV record, got: %#v", in.Answer)
+
+			resp, ok := in.Answer[0].(*dns.SRV)
+			require.True(t, ok, "expected SRV record, got: %T", in.Answer[0])
+
+			require.Equal(t, tc.expectedPort, int(resp.Port))
+		})
+	}
+}
