@@ -4,12 +4,11 @@
 package local
 
 import (
+	"context"
+
 	"github.com/hashicorp/consul/agent/grpc-external/limiter"
 	"github.com/hashicorp/consul/agent/proxycfg"
-	"github.com/hashicorp/consul/agent/proxycfg-sources/catalog"
 	structs "github.com/hashicorp/consul/agent/structs"
-	proxysnapshot "github.com/hashicorp/consul/internal/mesh/proxy-snapshot"
-	"github.com/hashicorp/consul/proto-public/pbresource"
 )
 
 // ConfigSource wraps a proxycfg.Manager to create watches on services
@@ -23,14 +22,13 @@ func NewConfigSource(cfgMgr ConfigManager) *ConfigSource {
 	return &ConfigSource{cfgMgr}
 }
 
-func (m *ConfigSource) Watch(proxyID *pbresource.ID, nodeName string, _ string) (
-	<-chan proxysnapshot.ProxySnapshot,
+func (m *ConfigSource) Watch(serviceID structs.ServiceID, nodeName string, _ string) (
+	<-chan *proxycfg.ConfigSnapshot,
 	limiter.SessionTerminatedChan,
 	proxycfg.SrcTerminatedChan,
-	proxysnapshot.CancelFunc,
+	context.CancelFunc,
 	error,
 ) {
-	serviceID := structs.NewServiceID(proxyID.Name, catalog.GetEnterpriseMetaFromResourceID(proxyID))
 	watchCh, cancelWatch := m.manager.Watch(proxycfg.ProxyID{
 		ServiceID: serviceID,
 		NodeName:  nodeName,
