@@ -265,7 +265,6 @@ func (h *handlerAPIGateway) handleGatewayConfigUpdate(ctx context.Context, u Upd
 		})
 
 		snap.APIGateway.BoundGatewayConfigLoaded = true
-		break
 	case *structs.APIGatewayConfigEntry:
 		snap.APIGateway.GatewayConfig = gwConf
 
@@ -280,7 +279,6 @@ func (h *handlerAPIGateway) handleGatewayConfigUpdate(ctx context.Context, u Upd
 		if err != nil {
 			return err
 		}
-		break
 	default:
 		return fmt.Errorf("invalid type for config entry: %T", resp.Entry)
 	}
@@ -398,7 +396,7 @@ func (h *handlerAPIGateway) handleRouteConfigUpdate(ctx context.Context, u Updat
 					name:       service.Name,
 					namespace:  service.NamespaceOrDefault(),
 					partition:  service.PartitionOrDefault(),
-					datacenter: h.stateConfig.source.Datacenter,
+					datacenter: h.source.Datacenter,
 				}
 
 				handler := &handlerUpstreams{handlerState: h.handlerState}
@@ -449,7 +447,7 @@ func (h *handlerAPIGateway) handleRouteConfigUpdate(ctx context.Context, u Updat
 				name:       service.Name,
 				namespace:  service.NamespaceOrDefault(),
 				partition:  service.PartitionOrDefault(),
-				datacenter: h.stateConfig.source.Datacenter,
+				datacenter: h.source.Datacenter,
 			}
 
 			handler := &handlerUpstreams{handlerState: h.handlerState}
@@ -491,7 +489,7 @@ func (h *handlerAPIGateway) recompileDiscoveryChains(snap *ConfigSnapshot) error
 
 	for name, listener := range snap.APIGateway.Listeners {
 		boundListener, ok := snap.APIGateway.BoundListeners[name]
-		if !(ok && snap.APIGateway.GatewayConfig.ListenerIsReady(name)) {
+		if !ok || !snap.APIGateway.GatewayConfig.ListenerIsReady(name) {
 			// Skip any listeners that don't have a bound listener. Once the bound listener is created, this will be run again.
 			// skip any listeners that might be in an invalid state
 			continue
