@@ -11,9 +11,9 @@ import (
 	"strings"
 	"time"
 
+	"github.com/go-viper/mapstructure/v2"
 	"github.com/miekg/dns"
 	"github.com/mitchellh/hashstructure"
-	"github.com/mitchellh/mapstructure"
 
 	"github.com/hashicorp/consul-net-rpc/go-msgpack/codec"
 	"github.com/hashicorp/go-multierror"
@@ -183,6 +183,9 @@ type ServiceConfigEntry struct {
 	Hash               uint64            `json:",omitempty" hash:"ignore"`
 	acl.EnterpriseMeta `hcl:",squash" mapstructure:",squash"`
 	RaftIndex          `hash:"ignore"`
+	// MaxRequestHeadersKB configures the maximum size in kilobytes for request headers
+	// sent from downstream clients to upstream services. If not set, uses Envoy's default.
+	MaxRequestHeadersKB *uint32 `json:",omitempty"`
 }
 
 func (e *ServiceConfigEntry) SetHash(h uint64) {
@@ -296,7 +299,7 @@ func (e *ServiceConfigEntry) Validate() error {
 	}
 
 	if e.Destination != nil {
-		if e.Destination.Addresses == nil || len(e.Destination.Addresses) == 0 {
+		if len(e.Destination.Addresses) == 0 {
 			validationErr = multierror.Append(validationErr, errors.New("Destination must contain at least one valid address"))
 		}
 
@@ -965,7 +968,7 @@ func (r *ServiceConfigRequest) CacheInfo() cache.RequestInfo {
 		UpstreamServiceNames: r.UpstreamServiceNames,
 		ProxyMode:            r.Mode,
 		MeshGatewayConfig:    r.MeshGateway,
-		Filter:               r.QueryOptions.Filter,
+		Filter:               r.Filter,
 	}, nil)
 	if err == nil {
 		// If there is an error, we don't set the key. A blank key forces
@@ -1083,8 +1086,8 @@ func (cfg *UpstreamConfig) normalize(named bool, entMeta *acl.EnterpriseMeta) er
 	if named {
 		// If the upstream namespace is omitted it inherits that of the enclosing
 		// config entry.
-		cfg.EnterpriseMeta.MergeNoWildcard(entMeta)
-		cfg.EnterpriseMeta.Normalize()
+		cfg.MergeNoWildcard(entMeta)
+		cfg.Normalize()
 	}
 
 	cfg.Protocol = strings.ToLower(cfg.Protocol)
@@ -1109,17 +1112,17 @@ func (cfg UpstreamConfig) validate(named bool) error {
 		if cfg.Name == WildcardSpecifier {
 			return fmt.Errorf("Wildcard name is not supported")
 		}
-		if cfg.EnterpriseMeta.NamespaceOrDefault() == WildcardSpecifier {
+		if cfg.NamespaceOrDefault() == WildcardSpecifier {
 			return fmt.Errorf("Wildcard namespace is not supported")
 		}
 	} else {
 		if cfg.Name != "" {
 			return fmt.Errorf("Name must be empty")
 		}
-		if cfg.EnterpriseMeta.NamespaceOrEmpty() != "" {
+		if cfg.NamespaceOrEmpty() != "" {
 			return fmt.Errorf("Namespace must be empty")
 		}
-		if cfg.EnterpriseMeta.PartitionOrEmpty() != "" {
+		if cfg.PartitionOrEmpty() != "" {
 			return fmt.Errorf("Partition must be empty")
 		}
 	}
