@@ -95,8 +95,8 @@ func (e *HTTPRouteConfigEntry) Normalize() error {
 		if parent.Kind == "" {
 			parent.Kind = APIGateway
 		}
-		parent.EnterpriseMeta.Merge(e.GetEnterpriseMeta())
-		parent.EnterpriseMeta.Normalize()
+		parent.Merge(e.GetEnterpriseMeta())
+		parent.Normalize()
 		e.Parents[i] = parent
 	}
 
@@ -121,8 +121,8 @@ func (e *HTTPRouteConfigEntry) Normalize() error {
 }
 
 func (e *HTTPRouteConfigEntry) normalizeHTTPService(service HTTPService) HTTPService {
-	service.EnterpriseMeta.Merge(e.GetEnterpriseMeta())
-	service.EnterpriseMeta.Normalize()
+	service.Merge(e.GetEnterpriseMeta())
+	service.Normalize()
 	if service.Weight <= 0 {
 		service.Weight = 1
 	}
@@ -605,14 +605,14 @@ func (e *TCPRouteConfigEntry) Normalize() error {
 		if parent.Kind == "" {
 			parent.Kind = APIGateway
 		}
-		parent.EnterpriseMeta.Merge(e.GetEnterpriseMeta())
-		parent.EnterpriseMeta.Normalize()
+		parent.Merge(e.GetEnterpriseMeta())
+		parent.Normalize()
 		e.Parents[i] = parent
 	}
 
 	for i, service := range e.Services {
-		service.EnterpriseMeta.Merge(e.GetEnterpriseMeta())
-		service.EnterpriseMeta.Normalize()
+		service.Merge(e.GetEnterpriseMeta())
+		service.Normalize()
 		e.Services[i] = service
 	}
 
