@@ -91,6 +91,7 @@ const (
 	RaftLogVerifierCheckpoint                   = 41 // Only used for log verifier, no-op on FSM.
 	ResourceOperationType                       = 42
 	UpdateVirtualIPRequestType                  = 43
+	CensusRequestType                           = 44
 )
 
 const (
@@ -160,6 +161,7 @@ var requestTypeStrings = map[MessageType]string{
 	RaftLogVerifierCheckpoint:       "RaftLogVerifierCheckpoint",
 	ResourceOperationType:           "Resource",
 	UpdateVirtualIPRequestType:      "UpdateManualVirtualIPRequestType",
+	CensusRequestType:               "Census",
 }
 
 const (
@@ -303,7 +305,7 @@ type QueryOptions struct {
 	// returned. Clients that wish to allow for stale results on error can set
 	// StaleIfError to a longer duration to change this behavior. It is ignored
 	// if the endpoint supports background refresh caching. See
-	// https://www.consul.io/api/index.html#agent-caching for more details.
+	// https://developer.hashicorp.com/api/index.html#agent-caching for more details.
 	MaxAge time.Duration `mapstructure:"max-age,omitempty"`
 
 	// MustRevalidate forces the agent to fetch a fresh version of a cached
@@ -317,7 +319,7 @@ type QueryOptions struct {
 	// if the servers are unavailable to fetch a fresh one. Only makes sense when
 	// UseCache is true and MaxAge is set to a lower, non-zero value. It is
 	// ignored if the endpoint supports background refresh caching. See
-	// https://www.consul.io/api/index.html#agent-caching for more details.
+	// https://developer.hashicorp.com/api/index.html#agent-caching for more details.
 	StaleIfError time.Duration `mapstructure:"stale-if-error,omitempty"`
 
 	// Filter specifies the go-bexpr filter expression to be used for
@@ -658,7 +660,7 @@ func (r *DCSpecificRequest) CacheInfo() cache.RequestInfo {
 }
 
 func (r *DCSpecificRequest) CacheMinIndex() uint64 {
-	return r.QueryOptions.MinQueryIndex
+	return r.MinQueryIndex
 }
 
 type OperatorUsageRequest struct {
@@ -719,7 +721,7 @@ func (r *ServiceDumpRequest) CacheInfo() cache.RequestInfo {
 }
 
 func (r *ServiceDumpRequest) CacheMinIndex() uint64 {
-	return r.QueryOptions.MinQueryIndex
+	return r.MinQueryIndex
 }
 
 // PartitionSpecificRequest is used to query about a specific partition.
@@ -742,7 +744,7 @@ func (r *PartitionSpecificRequest) CacheInfo() cache.RequestInfo {
 		Timeout:        r.MaxQueryTime,
 		MaxAge:         r.MaxAge,
 		MustRevalidate: r.MustRevalidate,
-		Key:            r.EnterpriseMeta.PartitionOrDefault(),
+		Key:            r.PartitionOrDefault(),
 	}
 }
 
@@ -841,7 +843,7 @@ func (r *ServiceSpecificRequest) CacheInfo() cache.RequestInfo {
 }
 
 func (r *ServiceSpecificRequest) CacheMinIndex() uint64 {
-	return r.QueryOptions.MinQueryIndex
+	return r.MinQueryIndex
 }
 
 // NodeSpecificRequest is used to request the information about a single node
@@ -1082,6 +1084,7 @@ type ServiceNode struct {
 	ServiceWeights           Weights
 	ServiceMeta              map[string]string
 	ServicePort              int
+	ServicePorts             ServicePorts `bexpr:"-"`
 	ServiceSocketPath        string
 	ServiceEnableTagOverride bool
 	ServiceProxy             ConnectProxyConfig
@@ -1140,6 +1143,7 @@ func (s *ServiceNode) PartialClone() *ServiceNode {
 		ServiceSocketPath:        s.ServiceSocketPath,
 		ServiceTaggedAddresses:   svcTaggedAddrs,
 		ServicePort:              s.ServicePort,
+		ServicePorts:             s.ServicePorts,
 		ServiceMeta:              nsmeta,
 		ServiceWeights:           s.ServiceWeights,
 		ServiceEnableTagOverride: s.ServiceEnableTagOverride,
@@ -1165,6 +1169,7 @@ func (s *ServiceNode) ToNodeService() *NodeService {
 		Address:           s.ServiceAddress,
 		TaggedAddresses:   s.ServiceTaggedAddresses,
 		Port:              s.ServicePort,
+		Ports:             s.ServicePorts,
 		SocketPath:        s.ServiceSocketPath,
 		Meta:              s.ServiceMeta,
 		Weights:           &s.ServiceWeights,
@@ -1297,6 +1302,83 @@ type ServiceAddress struct {
 	Port    int
 }
 
+type ServicePort struct {
+	Name    string
+	Port    int
+	Default bool
+}
+
+type ServicePorts []ServicePort
+
+func (sp ServicePorts) Validate() error {
+	if len(sp) == 0 {
+		return nil
+	}
+
+	seenName := make(map[string]struct{}, len(sp))
+	seenDefault := false
+	for _, p := range sp {
+		if strings.TrimSpace(p.Name) == "" {
+			return fmt.Errorf("Ports.Name cannot be empty")
+		}
+
+		if p.Port <= 0 {
+			return fmt.Errorf("Ports.Port must be greater than zero")
+		}
+
+		_, ok := seenName[p.Name]
+		if ok {
+			return fmt.Errorf("Ports.Name %q has to be unique", p.Name)
+		}
+
+		seenName[p.Name] = struct{}{}
+
+		if seenDefault && p.Default {
+			return fmt.Errorf("Only one port can be marked as default")
+		}
+
+		if p.Default {
+			seenDefault = true
+		}
+	}
+
+	if !seenDefault {
+		return fmt.Errorf("One of the Ports must be marked as Default")
+	}
+
+	return nil
+}
+
+// Two service ports are the same if they have the same combination of name and port
+func (sp ServicePorts) IsSame(other ServicePorts) bool {
+	if len(sp) != len(other) {
+		return false
+	}
+
+	seen := make(map[string]int, len(sp))
+	for _, p := range sp {
+		seen[p.Name] = p.Port
+	}
+
+	for _, p := range other {
+		port, ok := seen[p.Name]
+		if !ok || port != p.Port {
+			return false
+		}
+	}
+
+	return true
+}
+
+func (sp ServicePorts) GetPortWithName(name string) (int, bool) {
+	for _, p := range sp {
+		if p.Name == name {
+			return p.Port, true
+		}
+	}
+	return 0, false
+}
+
 func (a ServiceAddress) ToAPIServiceAddress() api.ServiceAddress {
 	return api.ServiceAddress{Address: a.Address, Port: a.Port}
 }
@@ -1316,8 +1398,9 @@ type NodeService struct {
 	Address           string
 	TaggedAddresses   map[string]ServiceAddress `json:",omitempty"`
 	Meta              map[string]string
-	Port              int    `json:",omitempty"`
-	SocketPath        string `json:",omitempty"` // TODO This might be integrated into Address somehow, but not sure about the ergonomics. Only one of (address,port) or socketpath can be defined.
+	Port              int          `json:",omitempty"`
+	Ports             ServicePorts `json:",omitempty" bexpr:"-"`
+	SocketPath        string       `json:",omitempty"` // TODO This might be integrated into Address somehow, but not sure about the ergonomics. Only one of (address,port) or socketpath can be defined.
 	Weights           *Weights
 	EnableTagOverride bool
 	Locality          *Locality `json:",omitempty" bexpr:"-"`
@@ -1384,6 +1467,16 @@ func (ns *NodeService) FillAuthzContext(ctx *acl.AuthorizerContext) {
 	ns.EnterpriseMeta.FillAuthzContext(ctx)
 }
 
+func (ns *NodeService) DefaultPort() int {
+	for _, p := range ns.Ports {
+		if p.Default {
+			return p.Port
+		}
+	}
+
+	return ns.Port
+}
+
 func (ns *NodeService) BestAddress(wan bool) (string, int) {
 	addr := ns.Address
 	port := ns.Port
@@ -1505,6 +1598,9 @@ func (s *NodeService) Validate() error {
 	}
 
 	if s.Kind == ServiceKindConnectProxy {
+		if len(s.Ports) > 0 {
+			result = multierror.Append(result, fmt.Errorf("Ports cannot be set for a %s", s.Kind))
+		}
 		if s.Port == 0 && s.SocketPath == "" {
 			result = multierror.Append(result, fmt.Errorf("Port or SocketPath must be set for a %s", s.Kind))
 		}
@@ -1515,6 +1611,14 @@ func (s *NodeService) Validate() error {
 		result = multierror.Append(result, commonValidation)
 	}
 
+	if len(s.Ports) > 0 && s.Port != 0 {
+		result = multierror.Append(result, fmt.Errorf("Cannot set both Port and Ports"))
+	}
+
+	if err := s.Ports.Validate(); err != nil {
+		result = multierror.Append(result, err)
+	}
+
 	return result
 }
 
@@ -1639,6 +1743,9 @@ func (s *NodeService) ValidateForAgent() error {
 
 	// Gateway validation
 	if s.IsGateway() {
+		if len(s.Ports) > 0 {
+			result = multierror.Append(result, fmt.Errorf("Ports cannot be set for a %s", s.Kind))
+		}
 		// Non-ingress gateways must have a port
 		if s.Port == 0 && s.Kind != ServiceKindIngressGateway && s.Kind != ServiceKindAPIGateway {
 			result = multierror.Append(result, fmt.Errorf("Port must be non-zero for a %s", s.Kind))
@@ -1707,6 +1814,7 @@ func (s *NodeService) IsSame(other *NodeService) bool {
 		!reflect.DeepEqual(s.Tags, other.Tags) ||
 		s.Address != other.Address ||
 		s.Port != other.Port ||
+		!s.Ports.IsSame(other.Ports) ||
 		s.SocketPath != other.SocketPath ||
 		!reflect.DeepEqual(s.TaggedAddresses, other.TaggedAddresses) ||
 		!reflect.DeepEqual(s.Weights, other.Weights) ||
@@ -1746,12 +1854,13 @@ func (s *ServiceNode) IsSameService(other *ServiceNode) bool {
 		s.ServiceAddress != other.ServiceAddress ||
 		!reflect.DeepEqual(s.ServiceTaggedAddresses, other.ServiceTaggedAddresses) ||
 		s.ServicePort != other.ServicePort ||
+		!s.ServicePorts.IsSame(other.ServicePorts) ||
 		!reflect.DeepEqual(s.ServiceMeta, other.ServiceMeta) ||
 		!reflect.DeepEqual(s.ServiceWeights, other.ServiceWeights) ||
 		s.ServiceEnableTagOverride != other.ServiceEnableTagOverride ||
 		!reflect.DeepEqual(s.ServiceProxy, other.ServiceProxy) ||
 		!reflect.DeepEqual(s.ServiceConnect, other.ServiceConnect) ||
-		!s.EnterpriseMeta.IsSame(&other.EnterpriseMeta) {
+		!s.IsSame(&other.EnterpriseMeta) {
 		return false
 	}
 
@@ -1781,6 +1890,7 @@ func (s *NodeService) ToServiceNode(node string) *ServiceNode {
 		ServiceAddress:           s.Address,
 		ServiceTaggedAddresses:   s.TaggedAddresses,
 		ServicePort:              s.Port,
+		ServicePorts:             s.Ports,
 		ServiceSocketPath:        s.SocketPath,
 		ServiceMeta:              s.Meta,
 		ServiceWeights:           theWeights,
@@ -1912,6 +2022,7 @@ type HealthCheckDefinition struct {
 	GRPCUseTLS                     bool                `json:",omitempty"`
 	AliasNode                      string              `json:",omitempty"`
 	AliasService                   string              `json:",omitempty"`
+	SessionName                    string              `json:",omitempty"`
 	TTL                            time.Duration       `json:",omitempty"`
 }
 
@@ -2284,7 +2395,7 @@ func NewCheckID(id types.CheckID, entMeta *acl.EnterpriseMeta) CheckID {
 	}
 
 	cid.EnterpriseMeta = *entMeta
-	cid.EnterpriseMeta.Normalize()
+	cid.Normalize()
 	return cid
 }
 
@@ -2294,7 +2405,7 @@ func NewCheckID(id types.CheckID, entMeta *acl.EnterpriseMeta) CheckID {
 func (cid CheckID) StringHashMD5() string {
 	hasher := md5.New()
 	hasher.Write([]byte(cid.ID))
-	cid.EnterpriseMeta.AddToHash(hasher, true)
+	cid.AddToHash(hasher, true)
 	return fmt.Sprintf("%x", hasher.Sum(nil))
 }
 
@@ -2303,7 +2414,7 @@ func (cid CheckID) StringHashMD5() string {
 func (cid CheckID) StringHashSHA256() string {
 	hasher := sha256.New()
 	hasher.Write([]byte(cid.ID))
-	cid.EnterpriseMeta.AddToHash(hasher, true)
+	cid.AddToHash(hasher, true)
 	return fmt.Sprintf("%x", hasher.Sum(nil))
 }
 
@@ -2320,7 +2431,7 @@ func NewServiceID(id string, entMeta *acl.EnterpriseMeta) ServiceID {
 	}
 
 	sid.EnterpriseMeta = *entMeta
-	sid.EnterpriseMeta.Normalize()
+	sid.Normalize()
 	return sid
 }
 
@@ -2333,7 +2444,7 @@ func (sid ServiceID) Matches(other ServiceID) bool {
 func (sid ServiceID) StringHashSHA256() string {
 	hasher := sha256.New()
 	hasher.Write([]byte(sid.ID))
-	sid.EnterpriseMeta.AddToHash(hasher, true)
+	sid.AddToHash(hasher, true)
 	return fmt.Sprintf("%x", hasher.Sum(nil))
 }
 
@@ -2394,7 +2505,7 @@ func NewServiceName(name string, entMeta *acl.EnterpriseMeta) ServiceName {
 	}
 
 	ret.EnterpriseMeta = *entMeta
-	ret.EnterpriseMeta.Normalize()
+	ret.Normalize()
 	return ret
 }
 
@@ -3178,3 +3289,31 @@ func (l *Locality) Validate() error {
 
 	return nil
 }
+
+// CensusRequest is used to perform operations on the local census
+type CensusRequest struct {
+	Action api.CensusOp
+	// PUT fields
+	ID   string    `json:",omitempty"`
+	TS   time.Time `json:",omitempty"`
+	Data []byte    `json:",omitempty"`
+	// PRUNE field
+	Cutoff  time.Time `json:",omitempty"`
+	Version uint16    `json:",omitempty"` // start at 1
+}
+
+// UtilizationBundleRequest is used to request a utilization bundle be generated via the API
+type UtilizationBundleRequest struct {
+	TodayOnly  bool
+	Message    string
+	SendReport bool
+
+	DCSpecificRequest
+}
+
+// UtilizationBundleResponse captures the server response when generating
+// manual utilization bundles via the System RPC/API.
+type UtilizationBundleResponse struct {
+	Bundle    []byte
+	QueryMeta QueryMeta
+}
