@@ -219,6 +219,18 @@ func testServiceNode(t *testing.T) *ServiceNode {
 			},
 		},
 		ServicePort: 8080,
+		ServicePorts: ServicePorts{
+			{
+				Name:    "http",
+				Port:    8080,
+				Default: true,
+			},
+			{
+				Name:    "https",
+				Port:    8443,
+				Default: false,
+			},
+		},
 		ServiceMeta: map[string]string{
 			"service": "metadata",
 		},
@@ -483,6 +495,35 @@ func TestStructs_ServiceNode_IsSameService(t *testing.T) {
 				sn.ServiceTaggedAddresses = nil
 			},
 		},
+		{
+			name: "ServiceMultiPort_Same",
+			setup: func(sn *ServiceNode) {
+				sn.ServicePorts = ServicePorts{
+					{
+						Name:    "http",
+						Port:    8080,
+						Default: true,
+					},
+					{
+						Name:    "https",
+						Port:    8443,
+						Default: false,
+					},
+				}
+			},
+			expect: true,
+		},
+		{
+			name: "ServiceMultiPort_Different",
+			setup: func(sn *ServiceNode) {
+				sn.ServicePorts = ServicePorts{
+					{
+						Name: "http",
+						Port: 1393,
+					},
+				}
+			},
+		},
 	}
 
 	run := func(t *testing.T, tc testcase) {
@@ -629,6 +670,129 @@ func TestStructs_Locality_Validate(t *testing.T) {
 	}
 }
 
+func TestStructs_NodeService_ValidateMultiPort(t *testing.T) {
+	type testCase struct {
+		Ns  NodeService
+		Err string
+	}
+
+	cases := map[string]testCase{
+		"valid": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    80,
+						Default: true,
+					},
+					{
+						Name:    "https",
+						Port:    443,
+						Default: false,
+					},
+				},
+			},
+			Err: "",
+		},
+		"no-default": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name: "http",
+						Port: 80,
+					},
+					{
+						Name: "https",
+						Port: 443,
+					},
+				},
+			},
+			Err: "One of the Ports must be marked as Default",
+		},
+		"multiple-default": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    80,
+						Default: true,
+					},
+					{
+						Name:    "https",
+						Port:    443,
+						Default: true,
+					},
+				},
+			},
+			Err: "Only one port can be marked as default",
+		},
+		"duplicate-names": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    80,
+						Default: true,
+					},
+					{
+						Name:    "http",
+						Port:    8080,
+						Default: false,
+					},
+				},
+			},
+			Err: "Ports.Name \"http\" has to be unique",
+		},
+		"empty-name": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "",
+						Port:    80,
+						Default: true,
+					},
+					{
+						Name:    "https",
+						Port:    80,
+						Default: false,
+					},
+				},
+			},
+			Err: "Ports.Name cannot be empty",
+		},
+		"zero-port": {
+			Ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    0,
+						Default: true,
+					},
+					{
+						Name:    "https",
+						Port:    80,
+						Default: false,
+					},
+				},
+			},
+			Err: "ports.port must be greater than zero",
+		},
+	}
+
+	for name, tc := range cases {
+		t.Run(name, func(t *testing.T) {
+			err := tc.Ns.Validate()
+
+			if tc.Err == "" {
+				require.NoError(t, err)
+			} else {
+				require.Error(t, err)
+				require.Contains(t, strings.ToLower(err.Error()), strings.ToLower(tc.Err))
+			}
+		})
+	}
+}
+
 func TestStructs_NodeService_ValidateMeshGateway(t *testing.T) {
 	type testCase struct {
 		Modify func(*NodeService)
@@ -1386,7 +1550,17 @@ func TestStructs_NodeService_IsSame(t *testing.T) {
 			"meta1": "value1",
 			"meta2": "value2",
 		},
-		Port:              1234,
+		Port: 1234,
+		Ports: ServicePorts{
+			{
+				Name: "http",
+				Port: 8080,
+			},
+			{
+				Name: "metrics",
+				Port: 9090,
+			},
+		},
 		EnableTagOverride: true,
 		Proxy: ConnectProxyConfig{
 			DestinationServiceName: "db",
@@ -1401,11 +1575,21 @@ func TestStructs_NodeService_IsSame(t *testing.T) {
 	}
 
 	other := &NodeService{
-		ID:                "node1",
-		Service:           "theservice",
-		Tags:              []string{"foo", "bar"},
-		Address:           "127.0.0.1",
-		Port:              1234,
+		ID:      "node1",
+		Service: "theservice",
+		Tags:    []string{"foo", "bar"},
+		Address: "127.0.0.1",
+		Port:    1234,
+		Ports: ServicePorts{
+			{
+				Name: "http",
+				Port: 8080,
+			},
+			{
+				Name: "metrics",
+				Port: 9090,
+			},
+		},
 		EnableTagOverride: true,
 		TaggedAddresses: map[string]ServiceAddress{
 			"wan": {
@@ -1480,6 +1664,71 @@ func TestStructs_NodeService_IsSame(t *testing.T) {
 		t.Fatalf("copy should be the same, but was\n %#v\nVS\n %#v", otherServiceNode, otherServiceNodeCopy2)
 	}
 	check(func() { other.TaggedAddresses["lan"] = ServiceAddress{Address: "127.0.0.1", Port: 9999} }, func() { other.TaggedAddresses["lan"] = ServiceAddress{Address: "127.0.0.1", Port: 3456} })
+	check(func() { other.Ports[0].Name = "port1" }, func() { other.Ports[0].Name = "http" })
+}
+
+func TestStructs_NodeService_DefaultPort(t *testing.T) {
+	type testCase struct {
+		ns       NodeService
+		expected int
+	}
+
+	cases := map[string]testCase{
+		"no_ports_with_port": {
+			ns: NodeService{
+				Port: 8080,
+			},
+			expected: 8080,
+		},
+		"no_ports_no_port": {
+			ns:       NodeService{},
+			expected: 0,
+		},
+		"with_ports_no_port": {
+			ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    8080,
+						Default: true,
+					},
+				},
+			},
+			expected: 8080,
+		},
+		"with_ports_with_port": {
+			ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name:    "http",
+						Port:    8080,
+						Default: true,
+					},
+				},
+				Port: 8081,
+			},
+			expected: 8080,
+		},
+		// Although this scenario isn't possible, helps improve coverage :D
+		"only_ports_no_default": {
+			ns: NodeService{
+				Ports: ServicePorts{
+					{
+						Name: "http",
+						Port: 8080,
+					},
+				},
+			},
+			expected: 0,
+		},
+	}
+
+	for name, tc := range cases {
+		t.Run(name, func(t *testing.T) {
+			actual := tc.ns.DefaultPort()
+			require.Equal(t, tc.expected, actual)
+		})
+	}
 }
 
 func TestStructs_HealthCheck_IsSame(t *testing.T) {
@@ -2808,8 +3057,8 @@ func makeFrank() *frankensteinStruct {
 }
 
 func makeMonster() *monsterStruct {
-	var d time.Duration = 9 * time.Hour
-	var t time.Time = time.Date(2008, 1, 2, 3, 4, 5, 0, time.UTC)
+	var d = 9 * time.Hour
+	var t = time.Date(2008, 1, 2, 3, 4, 5, 0, time.UTC)
 
 	return &monsterStruct{
 		Bool:    true,
@@ -3036,3 +3285,135 @@ func TestServiceList_Sort(t *testing.T) {
 		})
 	}
 }
+
+func TestServicePorts_Validate(t *testing.T) {
+	type testCase struct {
+		ports       ServicePorts
+		expectedErr string
+	}
+
+	cases := map[string]testCase{
+		"valid": {
+			ports: ServicePorts{
+				{
+					Name:    "http",
+					Port:    80,
+					Default: true,
+				},
+				{
+					Name: "https",
+					Port: 443,
+				},
+			},
+			expectedErr: "",
+		},
+		"empty": {
+			ports:       ServicePorts{},
+			expectedErr: "",
+		},
+		"invalid_duplicate_name": {
+			ports: ServicePorts{
+				{
+					Name:    "http",
+					Port:    80,
+					Default: true,
+				},
+				{
+					Name: "http",
+					Port: 8080,
+				},
+			},
+			expectedErr: "Ports.Name \"http\" has to be unique",
+		},
+		"invalid_port_name": {
+			ports: ServicePorts{
+				{
+					Name: "",
+					Port: 80,
+				},
+			},
+			expectedErr: "Ports.Name cannot be empty",
+		},
+		"invalid_port_number": {
+			ports: ServicePorts{
+				{
+					Name: "http",
+					Port: 0,
+				},
+			},
+			expectedErr: "Ports.Port must be greater than zero",
+		},
+		"invalid_negative_port_number": {
+			ports: ServicePorts{
+				{
+					Name: "http",
+					Port: -8080,
+				},
+			},
+			expectedErr: "Ports.Port must be greater than zero",
+		},
+		"invalid_no_default": {
+			ports: ServicePorts{
+				{
+					Name: "http",
+					Port: 80,
+				},
+			},
+			expectedErr: "One of the Ports must be marked as Default",
+		},
+		"invalid_multiple_default": {
+			ports: ServicePorts{
+				{
+					Name:    "http",
+					Port:    80,
+					Default: true,
+				},
+				{
+					Name:    "https",
+					Port:    443,
+					Default: true,
+				},
+			},
+			expectedErr: "Only one port can be marked as default",
+		},
+	}
+
+	for name, tc := range cases {
+		t.Run(name, func(t *testing.T) {
+			err := tc.ports.Validate()
+			if tc.expectedErr == "" {
+				require.NoError(t, err)
+			} else {
+				require.Error(t, err)
+				require.Contains(t, err.Error(), tc.expectedErr)
+			}
+		})
+	}
+
+}
+
+func TestServicePorts_GetPortWithName(t *testing.T) {
+	ports := ServicePorts{
+		{
+			Name:    "http",
+			Port:    80,
+			Default: true,
+		},
+		{
+			Name: "https",
+			Port: 443,
+		},
+	}
+
+	p, ok := ports.GetPortWithName("http")
+	require.True(t, ok)
+	require.Equal(t, 80, p)
+
+	p, ok = ports.GetPortWithName("https")
+	require.True(t, ok)
+	require.Equal(t, 443, p)
+
+	p, ok = ports.GetPortWithName("other")
+	require.False(t, ok)
+	require.Equal(t, 0, p)
+}
