@@ -19,6 +19,7 @@ import (
 	envoy_upstreams_v3 "github.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3"
 	envoy_matcher_v3 "github.com/envoyproxy/go-control-plane/envoy/type/matcher/v3"
 	envoy_type_v3 "github.com/envoyproxy/go-control-plane/envoy/type/v3"
+	"github.com/hashicorp/consul/agent/netutil"
 	"github.com/hashicorp/consul/agent/xds/config"
 	"github.com/hashicorp/consul/agent/xds/naming"
 
@@ -240,8 +241,16 @@ func makeJWTProviderCluster(p *structs.JWTProviderConfigEntry) (*envoy_cluster_v
 	}
 
 	if scheme == "https" {
+		sni := ""
+
+		// Set SNI to hostname when enabled.
+		if p.JSONWebKeySet.Remote.UseSNI {
+			sni = hostname
+		}
+
 		jwksTLSContext, err := makeUpstreamTLSTransportSocket(
 			&envoy_tls_v3.UpstreamTlsContext{
+				Sni: sni,
 				CommonTlsContext: &envoy_tls_v3.CommonTlsContext{
 					ValidationContextType: &envoy_tls_v3.CommonTlsContext_ValidationContext{
 						ValidationContext: makeJWTCertValidationContext(p.JSONWebKeySet.Remote.JWKSCluster),
@@ -856,7 +865,7 @@ func (s *ResourceGenerator) makeDestinationClusters(cfgSnap *proxycfg.ConfigSnap
 	clusters := make([]proto.Message, 0, len(cfgSnap.TerminatingGateway.DestinationServices))
 
 	for _, svcName := range cfgSnap.TerminatingGateway.ValidDestinations() {
-		svcConfig, _ := serviceConfigs[svcName]
+		svcConfig := serviceConfigs[svcName]
 		dest := svcConfig.Destination
 
 		for _, address := range dest.Addresses {
@@ -1097,9 +1106,18 @@ func (s *ResourceGenerator) makeAppCluster(cfgSnap *proxycfg.ConfigSnapshot, nam
 		endpoint = makePipeEndpoint(cfgSnap.Proxy.LocalServiceSocketPath)
 	} else {
 		addr := cfgSnap.Proxy.LocalServiceAddress
+
+		ds, err := netutil.IsDualStack(nil, true)
+		if err != nil {
+			s.Logger.Error("failed to determine if dual stack is supported, assuming not", "error", err)
+		}
 		if addr == "" {
 			addr = "127.0.0.1"
+			if ds {
+				addr = "::1"
+			}
 		}
+
 		endpoint = makeEndpoint(addr, port)
 	}
 
@@ -1753,10 +1771,7 @@ func (s *ResourceGenerator) makeGatewayCluster(snap *proxycfg.ConfigSnapshot, op
 		OutlierDetection: &envoy_cluster_v3.OutlierDetection{},
 	}
 
-	useEDS := true
-	if len(opts.hostnameEndpoints) > 0 {
-		useEDS = false
-	}
+	useEDS := len(opts.hostnameEndpoints) <= 0
 
 	// TCP keepalive settings can be enabled for terminating gateway upstreams or remote mesh gateways.
 	remoteUpstream := opts.isRemote || snap.Kind == structs.ServiceKindTerminatingGateway
@@ -1807,22 +1822,30 @@ func (s *ResourceGenerator) makeGatewayCluster(snap *proxycfg.ConfigSnapshot, op
 	return cluster
 }
 
+// configureClusterWithHostnames configures the Envoy cluster for service instance addressed by hostname.
+// We have Envoy do the DNS resolution by setting a DNS cluster type and passing the hostname endpoints via CDS.
+//
+// logger represents the hclog.Logger for logging.
+// cluster represents the Envoy cluster configuration.
+// dnsDiscoveryType indicates the DNS service discovery type.
+// hostnameEndpoints is a list of endpoints with a hostname as their address.
+// isRemote determines whether the cluster is in a remote DC or partition and we should prefer a WAN address.
+// onlyPassing determines whether endpoints that do not have a passing status should be considered unhealthy.
 func configureClusterWithHostnames(
 	logger hclog.Logger,
 	cluster *envoy_cluster_v3.Cluster,
 	dnsDiscoveryType string,
-	// hostnameEndpoints is a list of endpoints with a hostname as their address
 	hostnameEndpoints structs.CheckServiceNodes,
-	// isRemote determines whether the cluster is in a remote DC or partition and we should prefer a WAN address
 	isRemote bool,
-	// onlyPassing determines whether endpoints that do not have a passing status should be considered unhealthy
 	onlyPassing bool,
 ) {
-	// When a service instance is addressed by a hostname we have Envoy do the DNS resolution
-	// by setting a DNS cluster type and passing the hostname endpoints via CDS.
 	rate := 10 * time.Second
 	cluster.DnsRefreshRate = durationpb.New(rate)
 	cluster.DnsLookupFamily = envoy_cluster_v3.Cluster_V4_ONLY
+	ds, _ := netutil.IsDualStack(nil, true)
+	if ds {
+		cluster.DnsLookupFamily = envoy_cluster_v3.Cluster_ALL
+	}
 
 	envoyMaxEndpoints := 1
 	discoveryType := envoy_cluster_v3.Cluster_Type{Type: envoy_cluster_v3.Cluster_LOGICAL_DNS}
@@ -1926,7 +1949,11 @@ func (s *ResourceGenerator) makeExternalIPCluster(snap *proxycfg.ConfigSnapshot,
 func (s *ResourceGenerator) makeExternalHostnameCluster(snap *proxycfg.ConfigSnapshot, opts clusterOpts, discoveryType envoy_cluster_v3.Cluster_DiscoveryType) *envoy_cluster_v3.Cluster {
 	cfg := snap.GetGatewayConfig(s.Logger)
 	opts.connectTimeout = time.Duration(cfg.ConnectTimeoutMs) * time.Millisecond
-
+	dlf := envoy_cluster_v3.Cluster_V4_ONLY
+	ds, _ := netutil.IsDualStack(nil, true)
+	if ds {
+		dlf = envoy_cluster_v3.Cluster_ALL
+	}
 	cluster := &envoy_cluster_v3.Cluster{
 		Name:           opts.name,
 		ConnectTimeout: durationpb.New(opts.connectTimeout),
@@ -1934,7 +1961,7 @@ func (s *ResourceGenerator) makeExternalHostnameCluster(snap *proxycfg.ConfigSna
 		// Having an empty config enables outlier detection with default config.
 		OutlierDetection:     &envoy_cluster_v3.OutlierDetection{},
 		ClusterDiscoveryType: &envoy_cluster_v3.Cluster_Type{Type: discoveryType},
-		DnsLookupFamily:      envoy_cluster_v3.Cluster_V4_ONLY,
+		DnsLookupFamily:      dlf,
 	}
 
 	rate := 10 * time.Second
