@@ -7,7 +7,9 @@ import (
 	"errors"
 	"fmt"
 	"net"
+	"regexp"
 	"sort"
+	"strconv"
 	"strings"
 	"time"
 
@@ -615,7 +617,7 @@ func generateUpstreamIngressDomains(listenerKey proxycfg.IngressListenerKey, u s
 			continue
 		}
 
-		domainWithPort := fmt.Sprintf("%s:%d", h, listenerKey.Port)
+		domainWithPort := net.JoinHostPort(h, strconv.Itoa(listenerKey.Port))
 
 		// Do not add a duplicate domain if a hostname with port is already in the
 		// set
@@ -702,8 +704,13 @@ func (s *ResourceGenerator) makeUpstreamRouteForDiscoveryChain(
 			route := &envoy_route_v3.Route{}
 
 			if destination != nil {
-				if destination.PrefixRewrite != "" {
-					routeAction.Route.PrefixRewrite = destination.PrefixRewrite
+				// Gateway API: Path rewrite using replacePrefixMatch results in // or no rewrite CSL-12379-fix
+				// its a temporary fix for that issue as it needs to be fixed from envoy itself https://github.com/envoyproxy/envoy/issues/26055
+				ra := getRewriteActionForUserLogic(destination, routeMatch)
+				if ra != nil && ra.RegexRewrite != nil {
+					routeAction.Route.RegexRewrite = ra.RegexRewrite
+				} else if ra != nil && ra.PrefixRewrite != "" {
+					routeAction.Route.PrefixRewrite = ra.PrefixRewrite
 				}
 
 				if destination.RequestTimeout > 0 {
@@ -1244,3 +1251,40 @@ func injectHeaderManipToWeightedCluster(split *structs.ServiceSplit, c *envoy_ro
 	}
 	return nil
 }
+
+// getRewriteActionForUserLogic isolates the exact logic block you provided for testing.
+func getRewriteActionForUserLogic(destination *structs.ServiceRouteDestination, routeMatch *envoy_route_v3.RouteMatch) *envoy_route_v3.RouteAction {
+	routeAction := &envoy_route_v3.RouteAction{}
+
+	if destination == nil {
+		return routeAction
+	}
+	// --- THIS IS THE LOGIC UNDER TEST ---
+	if destination.PrefixRewrite == "" || destination.PrefixRewrite == "/" {
+		// Build the basic regex pattern
+		regexPattern := fmt.Sprintf(`^%s(/?)(.*)`, regexp.QuoteMeta(routeMatch.GetPrefix()))
+
+		// Check if the route match is case-insensitive.
+		// The proto field is CaseSensitive; 'false' means case-insensitive.
+		isCaseInsensitive := routeMatch.CaseSensitive != nil && !routeMatch.CaseSensitive.Value
+
+		// If the match is case-insensitive, the rewrite regex must be too.
+		if isCaseInsensitive {
+			// Prepend the regex flag for case-insensitivity
+			regexPattern = "(?i)" + regexPattern
+		}
+
+		routeAction.RegexRewrite = &envoy_matcher_v3.RegexMatchAndSubstitute{
+			Pattern: &envoy_matcher_v3.RegexMatcher{
+				Regex: regexPattern,
+			},
+			Substitution: `/\2`,
+		}
+	} else if destination.PrefixRewrite != "" {
+		// Use standard PrefixRewrite for replacement (e.g., /v2 -> /api/v2)
+		routeAction.PrefixRewrite = destination.PrefixRewrite
+	}
+	// --- END OF LOGIC UNDER TEST ---
+
+	return routeAction
+}
