@@ -5,6 +5,8 @@ package xds
 
 import (
 	"context"
+	"fmt"
+	"regexp"
 	"sort"
 	"sync"
 	"testing"
@@ -24,6 +26,7 @@ import (
 	envoy_tls_v3 "github.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3"
 	envoy_upstreams_v3 "github.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3"
 	envoy_discovery_v3 "github.com/envoyproxy/go-control-plane/envoy/service/discovery/v3"
+	envoy_matcher_v3 "github.com/envoyproxy/go-control-plane/envoy/type/matcher/v3"
 	envoy_type_v3 "github.com/envoyproxy/go-control-plane/envoy/type/v3"
 	"github.com/mitchellh/copystructure"
 	"github.com/stretchr/testify/require"
@@ -62,7 +65,7 @@ func newTestSnapshot(
 	if dbServiceProtocol != "" {
 		// Simulate ServiceManager injection of protocol
 		snap.Proxy.Upstreams[0].Config["protocol"] = dbServiceProtocol
-		snap.ConnectProxy.ConfigSnapshotUpstreams.UpstreamConfig = proxycfg.UpstreamsToMap(snap.Proxy.Upstreams)
+		snap.ConnectProxy.UpstreamConfig = proxycfg.UpstreamsToMap(snap.Proxy.Upstreams)
 	}
 	return snap
 }
@@ -77,7 +80,7 @@ type testManager struct {
 	cancels              chan structs.ServiceID
 }
 
-func newTestManager(t *testing.T) *testManager {
+func newTestManager() *testManager {
 	return &testManager{
 		stateChans:           map[structs.ServiceID]chan *proxycfg.ConfigSnapshot{},
 		drainChans:           map[structs.ServiceID]chan struct{}{},
@@ -186,7 +189,7 @@ func newTestServerDeltaScenario(
 	token string,
 	authCheckFrequency time.Duration,
 ) *testServerScenario {
-	mgr := newTestManager(t)
+	mgr := newTestManager()
 	envoy := NewTestEnvoy(t, proxyID, token)
 
 	sink := metrics.NewInmemSink(1*time.Minute, 1*time.Minute)
@@ -811,6 +814,12 @@ func makeTestRoute(t *testing.T, fixtureName string) *envoy_route_v3.RouteConfig
 									ClusterSpecifier: &envoy_route_v3.RouteAction_Cluster{
 										Cluster: "db.default.dc1.internal.11111111-2222-3333-4444-555555555555.consul",
 									},
+									RegexRewrite: &envoy_matcher_v3.RegexMatchAndSubstitute{
+										Pattern: &envoy_matcher_v3.RegexMatcher{
+											Regex: fmt.Sprintf(`^%s(/?)(.*)`, regexp.QuoteMeta("/")),
+										},
+										Substitution: `/\2`,
+									},
 								},
 							},
 						},
