@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package connect
 
 import (
@@ -5,7 +8,7 @@ import (
 	"testing"
 )
 
-func TestCatalogCommand_noTabs(t *testing.T) {
+func TestConnectCommand_noTabs(t *testing.T) {
 	t.Parallel()
 	if strings.ContainsRune(New().Help(), '\t') {
 		t.Fatal("help has tabs")
