@@ -121,7 +121,7 @@ func (c *cmd) Run(args []string) int {
 		return 1
 	}
 	if len(c.flags.Args()) > 0 {
-		c.UI.Error(fmt.Sprintf("Should have no non-flag arguments."))
+		c.UI.Error("Should have no non-flag arguments.")
 		return 1
 	}
 
@@ -323,9 +323,7 @@ func (c *cmd) configWatcher(client *api.Client) (proxyImpl.ConfigWatcher, error)
 
 		addr := config.LocalBindSocketPath
 		if addr == "" {
-			addr = fmt.Sprintf(
-				"%s:%d",
-				config.LocalBindAddress, config.LocalBindPort)
+			addr = net.JoinHostPort(config.LocalBindAddress, strconv.Itoa(config.LocalBindPort))
 		}
 
 		c.UI.Info(fmt.Sprintf(
@@ -348,12 +346,12 @@ func (c *cmd) configWatcher(client *api.Client) (proxyImpl.ConfigWatcher, error)
 					"knows the backend service address.")
 		}
 
-		c.UI.Info(fmt.Sprintf("   Public listener: %s:%d => %s", host, port, c.serviceAddr))
+		c.UI.Info(fmt.Sprintf("   Public listener: %s => %s", net.JoinHostPort(host, strconv.Itoa(port)), c.serviceAddr))
 		listener.BindAddress = host
 		listener.BindPort = port
 		listener.LocalServiceAddress = c.serviceAddr
 	} else {
-		c.UI.Info(fmt.Sprintf("   Public listener: Disabled"))
+		c.UI.Info("   Public listener: Disabled")
 	}
 
 	return proxyImpl.NewStaticConfigWatcher(&proxyImpl.Config{
