@@ -71,7 +71,7 @@ func (c *cmd) Run(args []string) int {
 		return 1
 	}
 
-	c.UI.Output(fmt.Sprintf("Intention deleted."))
+	c.UI.Output("Intention deleted.")
 	return 0
 }
 
