@@ -42,7 +42,7 @@ func (c *cmd) Run(args []string) int {
 		return 1
 	}
 	if n != 32 {
-		c.UI.Error(fmt.Sprintf("Couldn't read enough entropy. Generate more entropy!"))
+		c.UI.Error("Couldn't read enough entropy. Generate more entropy!")
 		return 1
 	}
 
