@@ -4,7 +4,6 @@
 package inspect
 
 import (
-	"fmt"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -46,7 +45,7 @@ func TestFormat(t *testing.T) {
 			actual, err := formatter.Format(&info)
 			require.NoError(t, err)
 
-			gName := fmt.Sprintf("%s", fmtName)
+			gName := fmtName
 
 			expected := golden(t, gName, actual)
 			require.Equal(t, expected, actual)
