@@ -45,6 +45,12 @@ type Controller struct {
 	logger           hclog.Logger
 	startCb          RuntimeCallback
 	stopCb           RuntimeCallback
+	// forceReconcileEvery is the time to wait after a successful reconciliation
+	// before forcing a reconciliation. The net result is a reconciliation of
+	// the managed type on a regular interval. This ensures that the state of the
+	// world is continually reconciled, hence correct in the face of missed events
+	// or other issues.
+	forceReconcileEvery time.Duration
 }
 
 type RuntimeCallback func(context.Context, Runtime)
@@ -65,10 +71,11 @@ func NewController(name string, managedType *pbresource.Type, indexes ...*index.
 	}
 
 	return &Controller{
-		name:             name,
-		managedTypeWatch: w,
-		watches:          make(map[string]*watch),
-		queries:          make(map[string]cache.Query),
+		name:                name,
+		managedTypeWatch:    w,
+		watches:             make(map[string]*watch),
+		queries:             make(map[string]cache.Query),
+		forceReconcileEvery: 8 * time.Hour,
 	}
 }
 
@@ -170,6 +177,15 @@ func (ctl *Controller) WithPlacement(placement Placement) *Controller {
 	return ctl
 }
 
+// WithForceReconcileEvery controls how often a resource gets periodically reconciled
+// to ensure that the state of the world is correct (8 hours is the default).
+// This exists for tests only and should not be customized by controller authors!
+func (ctl *Controller) WithForceReconcileEvery(duration time.Duration) *Controller {
+	ctl.logger.Warn("WithForceReconcileEvery is for testing only and should not be set by controllers")
+	ctl.forceReconcileEvery = duration
+	return ctl
+}
+
 // buildCache will construct a controller Cache given the watches/indexes that have
 // been added to the controller. This is mainly to be used by the TestController and
 // Manager when setting up how things
