@@ -15,6 +15,11 @@ export default (collection, clickable, attribute, isPresent, deletable) =>
       intention: clickable('a'),
       actions: clickable('label'),
       ...deletable(),
+      delete: clickable('[data-test-delete] [role="menuitem"]'),
+      confirmInlineDelete: clickable("#confirm-modal [data-test-id='confirm-action']", {
+        resetScope: true,
+        testContainer: 'body', // modal is rendered in the body
+      }),
     };
     return {
       scope: scope,
