@@ -17,8 +17,17 @@ const normalizedGatewayLabels = {
 
 export default Component.extend({
   tagName: '',
-  Name: computed('item.Kind', function () {
-    const name = normalizedGatewayLabels[this.item.Kind];
-    return name ? name : titleize(humanize(this.item.Kind));
+  Name: computed('item.Kind', {
+    get() {
+      if (this._Name !== undefined) {
+        return this._Name;
+      }
+      const name = normalizedGatewayLabels[this.item.Kind];
+      return name ? name : titleize(humanize(this.item.Kind));
+    },
+    set(_key, value) {
+      this._Name = value;
+      return this._Name;
+    },
   }),
 });
