@@ -5,4 +5,6 @@
 
 import Component from '@glimmer/component';
 
-export default class ConsulPolicySearchBarComponent extends Component {}
+export default class ConsulPolicySearchBarComponent extends Component {
+  dcs = [];
+}
