@@ -6,6 +6,7 @@
 import Helper from '@ember/component/helper';
 import { inject as service } from '@ember/service';
 import { action } from '@ember/object';
+import { scheduleOnce } from '@ember/runloop';
 
 export default class IsHrefHelper extends Helper {
   @service('router') router;
@@ -26,7 +27,13 @@ export default class IsHrefHelper extends Helper {
 
   @action
   routeWillChange(transition) {
-    this.next = transition.to.name.replace('.index', '');
+    const nextRoute = transition.to.name.replace('.index', '');
+    // Defer mutation + recompute without anonymous inline function
+    scheduleOnce('afterRender', this, this._commitNext, nextRoute);
+  }
+
+  _commitNext(nextRoute) {
+    this.next = nextRoute;
     this.recompute();
   }
 
