@@ -1,3 +1,8 @@
+/**
+ * Copyright (c) HashiCorp, Inc.
+ * SPDX-License-Identifier: BUSL-1.1
+ */
+
 import Model, { attr } from '@ember-data/model';
 import { computed } from '@ember/object';
 import { nullValue } from 'consul-ui/decorators/replace';
@@ -12,6 +17,7 @@ export default class Session extends Model {
   @attr('string') Name;
   @attr('string') Datacenter;
   @attr('string') Namespace;
+  @attr('string') Partition;
   @attr('string') Node;
   @attr('string') Behavior;
   @attr('string') TTL;
