@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: BUSL-1.1
  */
 
-import Service from 'ember-can/services/can';
+import Service from 'ember-can/services/abilities';
 
 export default class AbilitiesService extends Service {
   parse(str) {
