@@ -1,3 +1,8 @@
+/**
+ * Copyright (c) HashiCorp, Inc.
+ * SPDX-License-Identifier: BUSL-1.1
+ */
+
 import Service, { inject as service } from '@ember/service';
 import { StorageEventSource } from 'consul-ui/utils/dom/event-source';
 
@@ -8,7 +13,7 @@ export default class LocalStorageService extends Service {
   source(src, configuration) {
     const slug = src.split(':').pop();
     return new StorageEventSource(
-      configuration => {
+      (configuration) => {
         return this.repo.findBySlug(slug);
       },
       {
