@@ -1,3 +1,8 @@
+/**
+ * Copyright (c) HashiCorp, Inc.
+ * SPDX-License-Identifier: BUSL-1.1
+ */
+
 // rootURL in production equals `{{.ContentPath}}` and therefore is replaced
 // with the value of -ui-content-path. During development rootURL uses the
 // value as set in environment.js
@@ -8,9 +13,7 @@ module.exports = ({ appName, environment, rootURL, config }) => `
   <link rel="icon" href="${rootURL}assets/favicon.svg" type="image/svg+xml">
   <link rel="apple-touch-icon" href="${rootURL}assets/apple-touch-icon.png">
   <link integrity="" rel="stylesheet" href="${rootURL}assets/vendor.css">
-  <link integrity="" rel="stylesheet" href="${rootURL}assets/${
-    !['test', 'production'].includes(environment) ? 'debug' : appName
-}.css">
+  <link integrity="" rel="stylesheet" href="${rootURL}assets/${appName}.css">
   ${
     environment === 'test' ? `<link rel="stylesheet" href="${rootURL}assets/test-support.css">` : ``
   }
