@@ -3,10 +3,47 @@
  * SPDX-License-Identifier: BUSL-1.1
  */
 
+const isClassParentOfElement = function (_class, element) {
+  if (!element || !element.parentElement) {
+    return false;
+  }
+  if (element.parentElement.classList.contains(_class)) {
+    return true;
+  }
+
+  return isClassParentOfElement(_class, element.parentElement);
+};
+
 export default function (scenario, find, fillIn, triggerKeyEvent, currentPage) {
   const dont = `( don't| shouldn't| can't)?`;
+
+  const fillInCodeEditor = function (page, name, value) {
+    const valueElement = document.querySelector(`[aria-label="${name}"]`);
+
+    const isCodeEditorElement = isClassParentOfElement('cm-editor', valueElement);
+    const isCodeBlockElement = isClassParentOfElement('hds-code-block', valueElement);
+    if (isCodeEditorElement) {
+      const valueBlock = document.createElement('div');
+      valueBlock.innerHTML = value;
+      valueElement.innerHTML = '';
+      valueElement.appendChild(valueBlock);
+    } else {
+      if (isCodeBlockElement) {
+        throw new Error(`The ${name} editor is set to readonly`);
+      }
+
+      return page;
+    }
+
+    return page;
+  };
+
   const fillInElement = async function (page, name, value) {
     const cm = document.querySelector(`textarea[name="${name}"] + .CodeMirror`);
+    const codeEditor = document.querySelector(`[aria-label="${name}"]`);
+    if (isClassParentOfElement('cm-editor', codeEditor)) {
+      return fillInCodeEditor(page, name, value);
+    }
     if (cm) {
       if (!cm.CodeMirror.options.readOnly) {
         cm.CodeMirror.setValue(value);
@@ -82,6 +119,9 @@ export default function (scenario, find, fillIn, triggerKeyEvent, currentPage) {
         return res;
       }
     )
+    .then(['I fill in code editor "$name" with "$value"'], function (name, value) {
+      return fillInCodeEditor(currentPage(), name, value);
+    })
     .then(['I type "$text" into "$selector"'], function (text, selector) {
       return fillIn(selector, text);
     })
